# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags


class AugmentedManifestsListItem(AWSProperty):
    """
    `AugmentedManifestsListItem <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-comprehend-documentclassifier-augmentedmanifestslistitem.html>`__
    """

    props: PropsDictType = {
        "AttributeNames": ([str], True),
        "S3Uri": (str, True),
        "Split": (str, False),
    }


class DocumentClassifierDocuments(AWSProperty):
    """
    `DocumentClassifierDocuments <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-comprehend-documentclassifier-documentclassifierdocuments.html>`__
    """

    props: PropsDictType = {
        "S3Uri": (str, True),
        "TestS3Uri": (str, False),
    }


class DocumentReaderConfig(AWSProperty):
    """
    `DocumentReaderConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-comprehend-documentclassifier-documentreaderconfig.html>`__
    """

    props: PropsDictType = {
        "DocumentReadAction": (str, True),
        "DocumentReadMode": (str, False),
        "FeatureTypes": ([str], False),
    }


class DocumentClassifierInputDataConfig(AWSProperty):
    """
    `DocumentClassifierInputDataConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-comprehend-documentclassifier-documentclassifierinputdataconfig.html>`__
    """

    props: PropsDictType = {
        "AugmentedManifests": ([AugmentedManifestsListItem], False),
        "DataFormat": (str, False),
        "DocumentReaderConfig": (DocumentReaderConfig, False),
        "DocumentType": (str, False),
        "Documents": (DocumentClassifierDocuments, False),
        "LabelDelimiter": (str, False),
        "S3Uri": (str, False),
        "TestS3Uri": (str, False),
    }


class DocumentClassifierOutputDataConfig(AWSProperty):
    """
    `DocumentClassifierOutputDataConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-comprehend-documentclassifier-documentclassifieroutputdataconfig.html>`__
    """

    props: PropsDictType = {
        "KmsKeyId": (str, False),
        "S3Uri": (str, False),
    }


class VpcConfig(AWSProperty):
    """
    `VpcConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-comprehend-flywheel-vpcconfig.html>`__
    """

    props: PropsDictType = {
        "SecurityGroupIds": ([str], True),
        "Subnets": ([str], True),
    }


class DocumentClassifier(AWSObject):
    """
    `DocumentClassifier <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-comprehend-documentclassifier.html>`__
    """

    resource_type = "AWS::Comprehend::DocumentClassifier"

    props: PropsDictType = {
        "DataAccessRoleArn": (str, True),
        "DocumentClassifierName": (str, True),
        "InputDataConfig": (DocumentClassifierInputDataConfig, True),
        "LanguageCode": (str, True),
        "Mode": (str, False),
        "ModelKmsKeyId": (str, False),
        "ModelPolicy": (str, False),
        "OutputDataConfig": (DocumentClassifierOutputDataConfig, False),
        "Tags": (Tags, False),
        "VersionName": (str, False),
        "VolumeKmsKeyId": (str, False),
        "VpcConfig": (VpcConfig, False),
    }


class DataSecurityConfig(AWSProperty):
    """
    `DataSecurityConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-comprehend-flywheel-datasecurityconfig.html>`__
    """

    props: PropsDictType = {
        "DataLakeKmsKeyId": (str, False),
        "ModelKmsKeyId": (str, False),
        "VolumeKmsKeyId": (str, False),
        "VpcConfig": (VpcConfig, False),
    }


class DocumentClassificationConfig(AWSProperty):
    """
    `DocumentClassificationConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-comprehend-flywheel-documentclassificationconfig.html>`__
    """

    props: PropsDictType = {
        "Labels": ([str], False),
        "Mode": (str, True),
    }


class EntityTypesListItem(AWSProperty):
    """
    `EntityTypesListItem <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-comprehend-flywheel-entitytypeslistitem.html>`__
    """

    props: PropsDictType = {
        "Type": (str, True),
    }


class EntityRecognitionConfig(AWSProperty):
    """
    `EntityRecognitionConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-comprehend-flywheel-entityrecognitionconfig.html>`__
    """

    props: PropsDictType = {
        "EntityTypes": ([EntityTypesListItem], False),
    }


class TaskConfig(AWSProperty):
    """
    `TaskConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-comprehend-flywheel-taskconfig.html>`__
    """

    props: PropsDictType = {
        "DocumentClassificationConfig": (DocumentClassificationConfig, False),
        "EntityRecognitionConfig": (EntityRecognitionConfig, False),
        "LanguageCode": (str, True),
    }


class Flywheel(AWSObject):
    """
    `Flywheel <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-comprehend-flywheel.html>`__
    """

    resource_type = "AWS::Comprehend::Flywheel"

    props: PropsDictType = {
        "ActiveModelArn": (str, False),
        "DataAccessRoleArn": (str, True),
        "DataLakeS3Uri": (str, True),
        "DataSecurityConfig": (DataSecurityConfig, False),
        "FlywheelName": (str, True),
        "ModelType": (str, False),
        "Tags": (Tags, False),
        "TaskConfig": (TaskConfig, False),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType
from .validators import boolean, integer
from .validators.imagebuilder import (
    component_platforms,
    ebsinstanceblockdevicespecification_volume_type,
    imagepipeline_status,
    schedule_pipelineexecutionstartcondition,
)


class Component(AWSObject):
    """
    `Component <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-imagebuilder-component.html>`__
    """

    resource_type = "AWS::ImageBuilder::Component"

    props: PropsDictType = {
        "ChangeDescription": (str, False),
        "Data": (str, False),
        "Description": (str, False),
        "KmsKeyId": (str, False),
        "Name": (str, True),
        "Platform": (component_platforms, True),
        "SupportedOsVersions": ([str], False),
        "Tags": (dict, False),
        "Uri": (str, False),
        "Version": (str, True),
    }


class ComponentParameter(AWSProperty):
    """
    `ComponentParameter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-imagerecipe-componentparameter.html>`__
    """

    props: PropsDictType = {
        "Name": (str, True),
        "Value": ([str], True),
    }


class ContainerComponentConfiguration(AWSProperty):
    """
    `ContainerComponentConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-containerrecipe-componentconfiguration.html>`__
    """

    props: PropsDictType = {
        "ComponentArn": (str, False),
        "Parameters": ([ComponentParameter], False),
    }


class EbsInstanceBlockDeviceSpecification(AWSProperty):
    """
    `EbsInstanceBlockDeviceSpecification <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-imagerecipe-ebsinstanceblockdevicespecification.html>`__
    """

    props: PropsDictType = {
        "DeleteOnTermination": (boolean, False),
        "Encrypted": (boolean, False),
        "Iops": (integer, False),
        "KmsKeyId": (str, False),
        "SnapshotId": (str, False),
        "Throughput": (integer, False),
        "VolumeSize": (integer, False),
        "VolumeType": (ebsinstanceblockdevicespecification_volume_type, False),
    }


class InstanceBlockDeviceMapping(AWSProperty):
    """
    `InstanceBlockDeviceMapping <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-imagerecipe-instanceblockdevicemapping.html>`__
    """

    props: PropsDictType = {
        "DeviceName": (str, False),
        "Ebs": (EbsInstanceBlockDeviceSpecification, False),
        "NoDevice": (str, False),
        "VirtualName": (str, False),
    }


class InstanceConfiguration(AWSProperty):
    """
    `InstanceConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-containerrecipe-instanceconfiguration.html>`__
    """

    props: PropsDictType = {
        "BlockDeviceMappings": ([InstanceBlockDeviceMapping], False),
        "Image": (str, False),
    }


class TargetContainerRepository(AWSProperty):
    """
    `TargetContainerRepository <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-distributionconfiguration-targetcontainerrepository.html>`__
    """

    props: PropsDictType = {
        "RepositoryName": (str, False),
        "Service": (str, False),
    }


class ContainerRecipe(AWSObject):
    """
    `ContainerRecipe <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-imagebuilder-containerrecipe.html>`__
    """

    resource_type = "AWS::ImageBuilder::ContainerRecipe"

    props: PropsDictType = {
        "Components": ([ContainerComponentConfiguration], True),
        "ContainerType": (str, True),
        "Description": (str, False),
        "DockerfileTemplateData": (str, False),
        "DockerfileTemplateUri": (str, False),
        "ImageOsVersionOverride": (str, False),
        "InstanceConfiguration": (InstanceConfiguration, False),
        "KmsKeyId": (str, False),
        "Name": (str, True),
        "ParentImage": (str, True),
        "PlatformOverride": (str, False),
        "Tags": (dict, False),
        "TargetRepository": (TargetContainerRepository, True),
        "Version": (str, True),
        "WorkingDirectory": (str, False),
    }


class LaunchPermissionConfiguration(AWSProperty):
    """
    `LaunchPermissionConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-distributionconfiguration-launchpermissionconfiguration.html>`__
    """

    props: PropsDictType = {
        "OrganizationArns": ([str], False),
        "OrganizationalUnitArns": ([str], False),
        "UserGroups": ([str], False),
        "UserIds": ([str], False),
    }


class AmiDistributionConfiguration(AWSProperty):
    """
    `AmiDistributionConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-distributionconfiguration-amidistributionconfiguration.html>`__
    """

    props: PropsDictType = {
        "AmiTags": (dict, False),
        "Description": (str, False),
        "KmsKeyId": (str, False),
        "LaunchPermissionConfiguration": (LaunchPermissionConfiguration, False),
        "Name": (str, False),
        "TargetAccountIds": ([str], False),
    }


class ContainerDistributionConfiguration(AWSProperty):
    """
    `ContainerDistributionConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-distributionconfiguration-containerdistributionconfiguration.html>`__
    """

    props: PropsDictType = {
        "ContainerTags": ([str], False),
        "Description": (str, False),
        "TargetRepository": (TargetContainerRepository, False),
    }


class FastLaunchLaunchTemplateSpecification(AWSProperty):
    """
    `FastLaunchLaunchTemplateSpecification <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-distributionconfiguration-fastlaunchlaunchtemplatespecification.html>`__
    """

    props: PropsDictType = {
        "LaunchTemplateId": (str, False),
        "LaunchTemplateName": (str, False),
        "LaunchTemplateVersion": (str, False),
    }


class FastLaunchSnapshotConfiguration(AWSProperty):
    """
    `FastLaunchSnapshotConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-distributionconfiguration-fastlaunchsnapshotconfiguration.html>`__
    """

    props: PropsDictType = {
        "TargetResourceCount": (integer, False),
    }


class FastLaunchConfiguration(AWSProperty):
    """
    `FastLaunchConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-distributionconfiguration-fastlaunchconfiguration.html>`__
    """

    props: PropsDictType = {
        "AccountId": (str, False),
        "Enabled": (boolean, False),
        "LaunchTemplate": (FastLaunchLaunchTemplateSpecification, False),
        "MaxParallelLaunches": (integer, False),
        "SnapshotConfiguration": (FastLaunchSnapshotConfiguration, False),
    }


class LaunchTemplateConfiguration(AWSProperty):
    """
    `LaunchTemplateConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-distributionconfiguration-launchtemplateconfiguration.html>`__
    """

    props: PropsDictType = {
        "AccountId": (str, False),
        "LaunchTemplateId": (str, False),
        "SetDefaultVersion": (boolean, False),
    }


class Distribution(AWSProperty):
    """
    `Distribution <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-distributionconfiguration-distribution.html>`__
    """

    props: PropsDictType = {
        "AmiDistributionConfiguration": (AmiDistributionConfiguration, False),
        "ContainerDistributionConfiguration": (
            ContainerDistributionConfiguration,
            False,
        ),
        "FastLaunchConfigurations": ([FastLaunchConfiguration], False),
        "LaunchTemplateConfigurations": ([LaunchTemplateConfiguration], False),
        "LicenseConfigurationArns": ([str], False),
        "Region": (str, True),
    }


class DistributionConfiguration(AWSObject):
    """
    `DistributionConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-imagebuilder-distributionconfiguration.html>`__
    """

    resource_type = "AWS::ImageBuilder::DistributionConfiguration"

    props: PropsDictType = {
        "Description": (str, False),
        "Distributions": ([Distribution], True),
        "Name": (str, True),
        "Tags": (dict, False),
    }


class EcrConfiguration(AWSProperty):
    """
    `EcrConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-imagepipeline-ecrconfiguration.html>`__
    """

    props: PropsDictType = {
        "ContainerTags": ([str], False),
        "RepositoryName": (str, False),
    }


class ImageScanningConfiguration(AWSProperty):
    """
    `ImageScanningConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-imagepipeline-imagescanningconfiguration.html>`__
    """

    props: PropsDictType = {
        "EcrConfiguration": (EcrConfiguration, False),
        "ImageScanningEnabled": (boolean, False),
    }


class ImageTestsConfiguration(AWSProperty):
    """
    `ImageTestsConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-imagepipeline-imagetestsconfiguration.html>`__
    """

    props: PropsDictType = {
        "ImageTestsEnabled": (boolean, False),
        "TimeoutMinutes": (integer, False),
    }


class WorkflowParameter(AWSProperty):
    """
    `WorkflowParameter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-imagepipeline-workflowparameter.html>`__
    """

    props: PropsDictType = {
        "Name": (str, False),
        "Value": ([str], False),
    }


class WorkflowConfiguration(AWSProperty):
    """
    `WorkflowConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-imagepipeline-workflowconfiguration.html>`__
    """

    props: PropsDictType = {
        "OnFailure": (str, False),
        "ParallelGroup": (str, False),
        "Parameters": ([WorkflowParameter], False),
        "WorkflowArn": (str, False),
    }


class Image(AWSObject):
    """
    `Image <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-imagebuilder-image.html>`__
    """

    resource_type = "AWS::ImageBuilder::Image"

    props: PropsDictType = {
        "ContainerRecipeArn": (str, False),
        "DistributionConfigurationArn": (str, False),
        "EnhancedImageMetadataEnabled": (boolean, False),
        "ExecutionRole": (str, False),
        "ImageRecipeArn": (str, False),
        "ImageScanningConfiguration": (ImageScanningConfiguration, False),
        "ImageTestsConfiguration": (ImageTestsConfiguration, False),
        "InfrastructureConfigurationArn": (str, True),
        "Tags": (dict, False),
        "Workflows": ([WorkflowConfiguration], False),
    }


class Schedule(AWSProperty):
    """
    `Schedule <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-imagepipeline-schedule.html>`__
    """

    props: PropsDictType = {
        "PipelineExecutionStartCondition": (
            schedule_pipelineexecutionstartcondition,
            False,
        ),
        "ScheduleExpression": (str, False),
    }


class ImagePipeline(AWSObject):
    """
    `ImagePipeline <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-imagebuilder-imagepipeline.html>`__
    """

    resource_type = "AWS::ImageBuilder::ImagePipeline"

    props: PropsDictType = {
        "ContainerRecipeArn": (str, False),
        "Description": (str, False),
        "DistributionConfigurationArn": (str, False),
        "EnhancedImageMetadataEnabled": (boolean, False),
        "ExecutionRole": (str, False),
        "ImageRecipeArn": (str, False),
        "ImageScanningConfiguration": (ImageScanningConfiguration, False),
        "ImageTestsConfiguration": (ImageTestsConfiguration, False),
        "InfrastructureConfigurationArn": (str, True),
        "Name": (str, True),
        "Schedule": (Schedule, False),
        "Status": (imagepipeline_status, False),
        "Tags": (dict, False),
        "Workflows": ([WorkflowConfiguration], False),
    }


class SystemsManagerAgent(AWSProperty):
    """
    `SystemsManagerAgent <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-imagerecipe-systemsmanageragent.html>`__
    """

    props: PropsDictType = {
        "UninstallAfterBuild": (boolean, False),
    }


class AdditionalInstanceConfiguration(AWSProperty):
    """
    `AdditionalInstanceConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-imagerecipe-additionalinstanceconfiguration.html>`__
    """

    props: PropsDictType = {
        "SystemsManagerAgent": (SystemsManagerAgent, False),
        "UserDataOverride": (str, False),
    }


class ComponentConfiguration(AWSProperty):
    """
    `ComponentConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-imagerecipe-componentconfiguration.html>`__
    """

    props: PropsDictType = {
        "ComponentArn": (str, False),
        "Parameters": ([ComponentParameter], False),
    }


class ImageRecipe(AWSObject):
    """
    `ImageRecipe <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-imagebuilder-imagerecipe.html>`__
    """

    resource_type = "AWS::ImageBuilder::ImageRecipe"

    props: PropsDictType = {
        "AdditionalInstanceConfiguration": (AdditionalInstanceConfiguration, False),
        "BlockDeviceMappings": ([InstanceBlockDeviceMapping], False),
        "Components": ([ComponentConfiguration], True),
        "Description": (str, False),
        "Name": (str, True),
        "ParentImage": (str, True),
        "Tags": (dict, False),
        "Version": (str, True),
        "WorkingDirectory": (str, False),
    }


class InstanceMetadataOptions(AWSProperty):
    """
    `InstanceMetadataOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-infrastructureconfiguration-instancemetadataoptions.html>`__
    """

    props: PropsDictType = {
        "HttpPutResponseHopLimit": (integer, False),
        "HttpTokens": (str, False),
    }


class S3Logs(AWSProperty):
    """
    `S3Logs <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-infrastructureconfiguration-s3logs.html>`__
    """

    props: PropsDictType = {
        "S3BucketName": (str, False),
        "S3KeyPrefix": (str, False),
    }


class Logging(AWSProperty):
    """
    `Logging <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-infrastructureconfiguration-logging.html>`__
    """

    props: PropsDictType = {
        "S3Logs": (S3Logs, False),
    }


class InfrastructureConfiguration(AWSObject):
    """
    `InfrastructureConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-imagebuilder-infrastructureconfiguration.html>`__
    """

    resource_type = "AWS::ImageBuilder::InfrastructureConfiguration"

    props: PropsDictType = {
        "Description": (str, False),
        "InstanceMetadataOptions": (InstanceMetadataOptions, False),
        "InstanceProfileName": (str, True),
        "InstanceTypes": ([str], False),
        "KeyPair": (str, False),
        "Logging": (Logging, False),
        "Name": (str, True),
        "ResourceTags": (dict, False),
        "SecurityGroupIds": ([str], False),
        "SnsTopicArn": (str, False),
        "SubnetId": (str, False),
        "Tags": (dict, False),
        "TerminateInstanceOnFailure": (boolean, False),
    }


class IncludeResources(AWSProperty):
    """
    `IncludeResources <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-lifecyclepolicy-includeresources.html>`__
    """

    props: PropsDictType = {
        "Amis": (boolean, False),
        "Containers": (boolean, False),
        "Snapshots": (boolean, False),
    }


class Action(AWSProperty):
    """
    `Action <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-lifecyclepolicy-action.html>`__
    """

    props: PropsDictType = {
        "IncludeResources": (IncludeResources, False),
        "Type": (str, True),
    }


class LastLaunched(AWSProperty):
    """
    `LastLaunched <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-lifecyclepolicy-lastlaunched.html>`__
    """

    props: PropsDictType = {
        "Unit": (str, True),
        "Value": (integer, True),
    }


class AmiExclusionRules(AWSProperty):
    """
    `AmiExclusionRules <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-lifecyclepolicy-amiexclusionrules.html>`__
    """

    props: PropsDictType = {
        "IsPublic": (boolean, False),
        "LastLaunched": (LastLaunched, False),
        "Regions": ([str], False),
        "SharedAccounts": ([str], False),
        "TagMap": (dict, False),
    }


class ExclusionRules(AWSProperty):
    """
    `ExclusionRules <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-lifecyclepolicy-exclusionrules.html>`__
    """

    props: PropsDictType = {
        "Amis": (AmiExclusionRules, False),
        "TagMap": (dict, False),
    }


class Filter(AWSProperty):
    """
    `Filter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-lifecyclepolicy-filter.html>`__
    """

    props: PropsDictType = {
        "RetainAtLeast": (integer, False),
        "Type": (str, True),
        "Unit": (str, False),
        "Value": (integer, True),
    }


class PolicyDetail(AWSProperty):
    """
    `PolicyDetail <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-lifecyclepolicy-policydetail.html>`__
    """

    props: PropsDictType = {
        "Action": (Action, True),
        "ExclusionRules": (ExclusionRules, False),
        "Filter": (Filter, True),
    }


class RecipeSelection(AWSProperty):
    """
    `RecipeSelection <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-lifecyclepolicy-recipeselection.html>`__
    """

    props: PropsDictType = {
        "Name": (str, True),
        "SemanticVersion": (str, True),
    }


class ResourceSelection(AWSProperty):
    """
    `ResourceSelection <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-imagebuilder-lifecyclepolicy-resourceselection.html>`__
    """

    props: PropsDictType = {
        "Recipes": ([RecipeSelection], False),
        "TagMap": (dict, False),
    }


class LifecyclePolicy(AWSObject):
    """
    `LifecyclePolicy <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-imagebuilder-lifecyclepolicy.html>`__
    """

    resource_type = "AWS::ImageBuilder::LifecyclePolicy"

    props: PropsDictType = {
        "Description": (str, False),
        "ExecutionRole": (str, True),
        "Name": (str, True),
        "PolicyDetails": ([PolicyDetail], True),
        "ResourceSelection": (ResourceSelection, True),
        "ResourceType": (str, True),
        "Status": (str, False),
        "Tags": (dict, False),
    }


class Workflow(AWSObject):
    """
    `Workflow <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-imagebuilder-workflow.html>`__
    """

    resource_type = "AWS::ImageBuilder::Workflow"

    props: PropsDictType = {
        "ChangeDescription": (str, False),
        "Data": (str, False),
        "Description": (str, False),
        "KmsKeyId": (str, False),
        "Name": (str, True),
        "Tags": (dict, False),
        "Type": (str, True),
        "Uri": (str, False),
        "Version": (str, True),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, PropsDictType
from .validators import boolean


class AccountAlias(AWSObject):
    """
    `AccountAlias <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-supportapp-accountalias.html>`__
    """

    resource_type = "AWS::SupportApp::AccountAlias"

    props: PropsDictType = {
        "AccountAlias": (str, True),
    }


class SlackChannelConfiguration(AWSObject):
    """
    `SlackChannelConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-supportapp-slackchannelconfiguration.html>`__
    """

    resource_type = "AWS::SupportApp::SlackChannelConfiguration"

    props: PropsDictType = {
        "ChannelId": (str, True),
        "ChannelName": (str, False),
        "ChannelRoleArn": (str, True),
        "NotifyOnAddCorrespondenceToCase": (boolean, False),
        "NotifyOnCaseSeverity": (str, True),
        "NotifyOnCreateOrReopenCase": (boolean, False),
        "NotifyOnResolveCase": (boolean, False),
        "TeamId": (str, True),
    }


class SlackWorkspaceConfiguration(AWSObject):
    """
    `SlackWorkspaceConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-supportapp-slackworkspaceconfiguration.html>`__
    """

    resource_type = "AWS::SupportApp::SlackWorkspaceConfiguration"

    props: PropsDictType = {
        "TeamId": (str, True),
        "VersionId": (str, False),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean, integer
from .validators.cassandra import (
    validate_billingmode_mode,
    validate_clusteringkeycolumn_orderby,
)


class ReplicationSpecification(AWSProperty):
    """
    `ReplicationSpecification <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-keyspace-replicationspecification.html>`__
    """

    props: PropsDictType = {
        "RegionList": ([str], False),
        "ReplicationStrategy": (str, False),
    }


class Keyspace(AWSObject):
    """
    `Keyspace <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-keyspace.html>`__
    """

    resource_type = "AWS::Cassandra::Keyspace"

    props: PropsDictType = {
        "KeyspaceName": (str, False),
        "ReplicationSpecification": (ReplicationSpecification, False),
        "Tags": (Tags, False),
    }


class ProvisionedThroughput(AWSProperty):
    """
    `ProvisionedThroughput <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-provisionedthroughput.html>`__
    """

    props: PropsDictType = {
        "ReadCapacityUnits": (integer, True),
        "WriteCapacityUnits": (integer, True),
    }


class BillingMode(AWSProperty):
    """
    `BillingMode <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-billingmode.html>`__
    """

    props: PropsDictType = {
        "Mode": (validate_billingmode_mode, True),
        "ProvisionedThroughput": (ProvisionedThroughput, False),
    }


class Column(AWSProperty):
    """
    `Column <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-column.html>`__
    """

    props: PropsDictType = {
        "ColumnName": (str, True),
        "ColumnType": (str, True),
    }


class ClusteringKeyColumn(AWSProperty):
    """
    `ClusteringKeyColumn <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-clusteringkeycolumn.html>`__
    """

    props: PropsDictType = {
        "Column": (Column, True),
        "OrderBy": (validate_clusteringkeycolumn_orderby, False),
    }


class EncryptionSpecification(AWSProperty):
    """
    `EncryptionSpecification <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cassandra-table-encryptionspecification.html>`__
    """

    props: PropsDictType = {
        "EncryptionType": (str, True),
        "KmsKeyIdentifier": (str, False),
    }


class Table(AWSObject):
    """
    `Table <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cassandra-table.html>`__
    """

    resource_type = "AWS::Cassandra::Table"

    props: PropsDictType = {
        "BillingMode": (BillingMode, False),
        "ClientSideTimestampsEnabled": (boolean, False),
        "ClusteringKeyColumns": ([ClusteringKeyColumn], False),
        "DefaultTimeToLive": (integer, False),
        "EncryptionSpecification": (EncryptionSpecification, False),
        "KeyspaceName": (str, True),
        "PartitionKeyColumns": ([Column], True),
        "PointInTimeRecoveryEnabled": (boolean, False),
        "RegularColumns": ([Column], False),
        "TableName": (str, False),
        "Tags": (Tags, False),
    }



# Converted from s3_processor located at:
# https://github.com/awslabs/serverless-application-model/blob/dbc54b5d0cd31bf5cebd16d765b74aee9eb34641/examples/2016-10-31/s3_processor/template.yaml

from troposphere import Template
from troposphere.serverless import DeploymentPreference, Function

t = Template()

t.set_description(
    "A function that uses the configured traffic shifting type "
    "for a canary deployment."
)

t.set_transform("AWS::Serverless-2016-10-31")

t.add_resource(
    Function(
        "Function",
        Handler="index.handler",
        Runtime="nodejs6.10",
        CodeUri="s3://<bucket>/function.zip",
        AutoPublishAlias="live",
        DeploymentPreference=DeploymentPreference(
            Enabled=True, Type="Canary10Percent5Minutes"
        ),
    )
)

print(t.to_json())



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean, integer
from .validators.config import ONE_HOUR  # noqa: F401
from .validators.config import SIX_HOURS  # noqa: F401
from .validators.config import THREE_HOURS  # noqa: F401
from .validators.config import TWELVE_HOURS  # noqa: F401
from .validators.config import TWENTYFOUR_HOURS  # noqa: F401
from .validators.config import validate_source_details


class AggregationAuthorization(AWSObject):
    """
    `AggregationAuthorization <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-config-aggregationauthorization.html>`__
    """

    resource_type = "AWS::Config::AggregationAuthorization"

    props: PropsDictType = {
        "AuthorizedAccountId": (str, True),
        "AuthorizedAwsRegion": (str, True),
        "Tags": (Tags, False),
    }


class Compliance(AWSProperty):
    """
    `Compliance <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-config-configrule-compliance.html>`__
    """

    props: PropsDictType = {
        "Type": (str, False),
    }


class EvaluationModeConfiguration(AWSProperty):
    """
    `EvaluationModeConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-config-configrule-evaluationmodeconfiguration.html>`__
    """

    props: PropsDictType = {
        "Mode": (str, False),
    }


class Scope(AWSProperty):
    """
    `Scope <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-config-configrule-scope.html>`__
    """

    props: PropsDictType = {
        "ComplianceResourceId": (str, False),
        "ComplianceResourceTypes": ([str], False),
        "TagKey": (str, False),
        "TagValue": (str, False),
    }


class CustomPolicyDetails(AWSProperty):
    """
    `CustomPolicyDetails <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-config-configrule-custompolicydetails.html>`__
    """

    props: PropsDictType = {
        "EnableDebugLogDelivery": (boolean, False),
        "PolicyRuntime": (str, False),
        "PolicyText": (str, False),
    }


class SourceDetails(AWSProperty):
    """
    `SourceDetails <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-config-configrule-sourcedetail.html>`__
    """

    props: PropsDictType = {
        "EventSource": (str, True),
        "MaximumExecutionFrequency": (str, False),
        "MessageType": (str, True),
    }

    def validate(self):
        validate_source_details(self)


class Source(AWSProperty):
    """
    `Source <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-config-configrule-source.html>`__
    """

    props: PropsDictType = {
        "CustomPolicyDetails": (CustomPolicyDetails, False),
        "Owner": (str, True),
        "SourceDetails": ([SourceDetails], False),
        "SourceIdentifier": (str, False),
    }


class ConfigRule(AWSObject):
    """
    `ConfigRule <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-config-configrule.html>`__
    """

    resource_type = "AWS::Config::ConfigRule"

    props: PropsDictType = {
        "Compliance": (Compliance, False),
        "ConfigRuleName": (str, False),
        "Description": (str, False),
        "EvaluationModes": ([EvaluationModeConfiguration], False),
        "InputParameters": (dict, False),
        "MaximumExecutionFrequency": (str, False),
        "Scope": (Scope, False),
        "Source": (Source, True),
    }


class AccountAggregationSources(AWSProperty):
    """
    `AccountAggregationSources <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-config-configurationaggregator-accountaggregationsource.html>`__
    """

    props: PropsDictType = {
        "AccountIds": ([str], True),
        "AllAwsRegions": (boolean, False),
        "AwsRegions": ([str], False),
    }


class OrganizationAggregationSource(AWSProperty):
    """
    `OrganizationAggregationSource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-config-configurationaggregator-organizationaggregationsource.html>`__
    """

    props: PropsDictType = {
        "AllAwsRegions": (boolean, False),
        "AwsRegions": ([str], False),
        "RoleArn": (str, True),
    }


class ConfigurationAggregator(AWSObject):
    """
    `ConfigurationAggregator <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-config-configurationaggregator.html>`__
    """

    resource_type = "AWS::Config::ConfigurationAggregator"

    props: PropsDictType = {
        "AccountAggregationSources": ([AccountAggregationSources], False),
        "ConfigurationAggregatorName": (str, False),
        "OrganizationAggregationSource": (OrganizationAggregationSource, False),
        "Tags": (Tags, False),
    }


class ExclusionByResourceTypes(AWSProperty):
    """
    `ExclusionByResourceTypes <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-config-configurationrecorder-exclusionbyresourcetypes.html>`__
    """

    props: PropsDictType = {
        "ResourceTypes": ([str], True),
    }


class RecordingStrategy(AWSProperty):
    """
    `RecordingStrategy <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-config-configurationrecorder-recordingstrategy.html>`__
    """

    props: PropsDictType = {
        "UseOnly": (str, True),
    }


class RecordingGroup(AWSProperty):
    """
    `RecordingGroup <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-config-configurationrecorder-recordinggroup.html>`__
    """

    props: PropsDictType = {
        "AllSupported": (boolean, False),
        "ExclusionByResourceTypes": (ExclusionByResourceTypes, False),
        "IncludeGlobalResourceTypes": (boolean, False),
        "RecordingStrategy": (RecordingStrategy, False),
        "ResourceTypes": ([str], False),
    }


class RecordingModeOverride(AWSProperty):
    """
    `RecordingModeOverride <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-config-configurationrecorder-recordingmodeoverride.html>`__
    """

    props: PropsDictType = {
        "Description": (str, False),
        "RecordingFrequency": (str, True),
        "ResourceTypes": ([str], True),
    }


class RecordingMode(AWSProperty):
    """
    `RecordingMode <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-config-configurationrecorder-recordingmode.html>`__
    """

    props: PropsDictType = {
        "RecordingFrequency": (str, True),
        "RecordingModeOverrides": ([RecordingModeOverride], False),
    }


class ConfigurationRecorder(AWSObject):
    """
    `ConfigurationRecorder <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-config-configurationrecorder.html>`__
    """

    resource_type = "AWS::Config::ConfigurationRecorder"

    props: PropsDictType = {
        "Name": (str, False),
        "RecordingGroup": (RecordingGroup, False),
        "RecordingMode": (RecordingMode, False),
        "RoleARN": (str, True),
    }


class ConformancePackInputParameter(AWSProperty):
    """
    `ConformancePackInputParameter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-config-organizationconformancepack-conformancepackinputparameter.html>`__
    """

    props: PropsDictType = {
        "ParameterName": (str, True),
        "ParameterValue": (str, True),
    }


class TemplateSSMDocumentDetails(AWSProperty):
    """
    `TemplateSSMDocumentDetails <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-config-conformancepack-templatessmdocumentdetails.html>`__
    """

    props: PropsDictType = {
        "DocumentName": (str, False),
        "DocumentVersion": (str, False),
    }


class ConformancePack(AWSObject):
    """
    `ConformancePack <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-config-conformancepack.html>`__
    """

    resource_type = "AWS::Config::ConformancePack"

    props: PropsDictType = {
        "ConformancePackInputParameters": ([ConformancePackInputParameter], False),
        "ConformancePackName": (str, True),
        "DeliveryS3Bucket": (str, False),
        "DeliveryS3KeyPrefix": (str, False),
        "TemplateBody": (str, False),
        "TemplateS3Uri": (str, False),
        "TemplateSSMDocumentDetails": (TemplateSSMDocumentDetails, False),
    }


class ConfigSnapshotDeliveryProperties(AWSProperty):
    """
    `ConfigSnapshotDeliveryProperties <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-config-deliverychannel-configsnapshotdeliveryproperties.html>`__
    """

    props: PropsDictType = {
        "DeliveryFrequency": (str, False),
    }


class DeliveryChannel(AWSObject):
    """
    `DeliveryChannel <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-config-deliverychannel.html>`__
    """

    resource_type = "AWS::Config::DeliveryChannel"

    props: PropsDictType = {
        "ConfigSnapshotDeliveryProperties": (ConfigSnapshotDeliveryProperties, False),
        "Name": (str, False),
        "S3BucketName": (str, True),
        "S3KeyPrefix": (str, False),
        "S3KmsKeyArn": (str, False),
        "SnsTopicARN": (str, False),
    }


class OrganizationCustomPolicyRuleMetadata(AWSProperty):
    """
    `OrganizationCustomPolicyRuleMetadata <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-config-organizationconfigrule-organizationcustompolicyrulemetadata.html>`__
    """

    props: PropsDictType = {
        "DebugLogDeliveryAccounts": ([str], False),
        "Description": (str, False),
        "InputParameters": (str, False),
        "MaximumExecutionFrequency": (str, False),
        "OrganizationConfigRuleTriggerTypes": ([str], False),
        "PolicyText": (str, True),
        "ResourceIdScope": (str, False),
        "ResourceTypesScope": ([str], False),
        "Runtime": (str, True),
        "TagKeyScope": (str, False),
        "TagValueScope": (str, False),
    }


class OrganizationCustomRuleMetadata(AWSProperty):
    """
    `OrganizationCustomRuleMetadata <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-config-organizationconfigrule-organizationcustomrulemetadata.html>`__
    """

    props: PropsDictType = {
        "Description": (str, False),
        "InputParameters": (str, False),
        "LambdaFunctionArn": (str, True),
        "MaximumExecutionFrequency": (str, False),
        "OrganizationConfigRuleTriggerTypes": ([str], True),
        "ResourceIdScope": (str, False),
        "ResourceTypesScope": ([str], False),
        "TagKeyScope": (str, False),
        "TagValueScope": (str, False),
    }


class OrganizationManagedRuleMetadata(AWSProperty):
    """
    `OrganizationManagedRuleMetadata <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-config-organizationconfigrule-organizationmanagedrulemetadata.html>`__
    """

    props: PropsDictType = {
        "Description": (str, False),
        "InputParameters": (str, False),
        "MaximumExecutionFrequency": (str, False),
        "ResourceIdScope": (str, False),
        "ResourceTypesScope": ([str], False),
        "RuleIdentifier": (str, True),
        "TagKeyScope": (str, False),
        "TagValueScope": (str, False),
    }


class OrganizationConfigRule(AWSObject):
    """
    `OrganizationConfigRule <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-config-organizationconfigrule.html>`__
    """

    resource_type = "AWS::Config::OrganizationConfigRule"

    props: PropsDictType = {
        "ExcludedAccounts": ([str], False),
        "OrganizationConfigRuleName": (str, True),
        "OrganizationCustomPolicyRuleMetadata": (
            OrganizationCustomPolicyRuleMetadata,
            False,
        ),
        "OrganizationCustomRuleMetadata": (OrganizationCustomRuleMetadata, False),
        "OrganizationManagedRuleMetadata": (OrganizationManagedRuleMetadata, False),
    }


class OrganizationConformancePack(AWSObject):
    """
    `OrganizationConformancePack <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-config-organizationconformancepack.html>`__
    """

    resource_type = "AWS::Config::OrganizationConformancePack"

    props: PropsDictType = {
        "ConformancePackInputParameters": ([ConformancePackInputParameter], False),
        "DeliveryS3Bucket": (str, False),
        "DeliveryS3KeyPrefix": (str, False),
        "ExcludedAccounts": ([str], False),
        "OrganizationConformancePackName": (str, True),
        "TemplateBody": (str, False),
        "TemplateS3Uri": (str, False),
    }


class SsmControls(AWSProperty):
    """
    `SsmControls <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-config-remediationconfiguration-ssmcontrols.html>`__
    """

    props: PropsDictType = {
        "ConcurrentExecutionRatePercentage": (integer, False),
        "ErrorPercentage": (integer, False),
    }


class ExecutionControls(AWSProperty):
    """
    `ExecutionControls <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-config-remediationconfiguration-executioncontrols.html>`__
    """

    props: PropsDictType = {
        "SsmControls": (SsmControls, False),
    }


class RemediationConfiguration(AWSObject):
    """
    `RemediationConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-config-remediationconfiguration.html>`__
    """

    resource_type = "AWS::Config::RemediationConfiguration"

    props: PropsDictType = {
        "Automatic": (boolean, False),
        "ConfigRuleName": (str, True),
        "ExecutionControls": (ExecutionControls, False),
        "MaximumAutomaticAttempts": (integer, False),
        "Parameters": (dict, False),
        "ResourceType": (str, False),
        "RetryAttemptSeconds": (integer, False),
        "TargetId": (str, True),
        "TargetType": (str, True),
        "TargetVersion": (str, False),
    }


class StoredQuery(AWSObject):
    """
    `StoredQuery <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-config-storedquery.html>`__
    """

    resource_type = "AWS::Config::StoredQuery"

    props: PropsDictType = {
        "QueryDescription": (str, False),
        "QueryExpression": (str, True),
        "QueryName": (str, True),
        "Tags": (Tags, False),
    }


class ResourceValue(AWSProperty):
    """
    `ResourceValue <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-config-remediationconfiguration-resourcevalue.html>`__
    """

    props: PropsDictType = {
        "Value": (str, False),
    }


class StaticValue(AWSProperty):
    """
    `StaticValue <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-config-remediationconfiguration-staticvalue.html>`__
    """

    props: PropsDictType = {
        "Values": ([str], False),
    }


class RemediationParameterValue(AWSProperty):
    """
    `RemediationParameterValue <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-config-remediationconfiguration-remediationparametervalue.html>`__
    """

    props: PropsDictType = {
        "ResourceValue": (ResourceValue, False),
        "StaticValue": (StaticValue, False),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.


import re

from .. import AWSHelperFn
from . import integer, integer_range, network_port, positive_integer, tags_or_list


def validate_network_port(x):
    """
    Property: DBCluster.Port
    Property: DBInstance.Port
    Property: OptionConfiguration.Port
    """
    return network_port(x)


def validate_str_or_int(x):
    """
    Property: DBInstance.AllocatedStorage
    """
    if isinstance(x, (AWSHelperFn, str, int)):
        return x
    raise ValueError(f"Value {x} of type {type(x)} must be either str or int")


def validate_tags_or_list(x):
    """
    Property: DBCluster.Tags
    Property: DBClusterParameterGroup.Tags
    Property: DBInstance.Tags
    Property: DBParameterGroup.Tags
    Property: DBSecurityGroup.Tags
    Property: DBSubnetGroup.Tags
    Property: OptionGroup.Tags
    """
    return tags_or_list(x)


def validate_backtrack_window(x):
    """
    Property: DBCluster.BacktrackWindow
    """
    return integer_range(0, 259200)(x)


def validate_iops(iops):
    """
    DBInstance Iops validation rules.
    Property: DBInstance.Iops
    """

    iops = integer(iops)
    if int(iops) == 0:
        return iops
    if int(iops) < 1000:
        raise ValueError("DBInstance Iops, if set, must be greater than 1000.")
    return iops


def validate_storage_type(storage_type):
    """
    Validate StorageType for DBInstance
    Property:
    """

    VALID_STORAGE_TYPES = ("standard", "gp2", "gp3", "io1")

    if storage_type not in VALID_STORAGE_TYPES:
        raise ValueError(
            "DBInstance StorageType must be one of: %s" % ", ".join(VALID_STORAGE_TYPES)
        )
    return storage_type


def validate_engine(engine):
    """
    Validate database Engine for DBInstance
    Property: DBInstance.Engine
    Property: DBCluster.Engine
    """

    VALID_DB_ENGINES = (
        "MySQL",
        "mysql",
        "oracle-se1",
        "oracle-se2",
        "oracle-se",
        "oracle-ee",
        "sqlserver-ee",
        "sqlserver-se",
        "sqlserver-ex",
        "sqlserver-web",
        "postgres",
        "aurora",
        "aurora-mysql",
        "aurora-postgresql",
        "mariadb",
        "custom-oracle-ee",
        "custom-oracle-ee-cdb",
        "custom-sqlserver-ee",
        "custom-sqlserver-se",
        "custom-sqlserver-web",
    )

    if engine not in VALID_DB_ENGINES:
        raise ValueError(
            "DBInstance Engine must be one of: %s" % ", ".join(VALID_DB_ENGINES)
        )
    return engine


def validate_engine_mode(engine_mode):
    """
    Validate database EngineMode for DBCluster
    Property: DBCluster.EngineMode
    """

    VALID_DB_ENGINE_MODES = (
        "provisioned",
        "serverless",
        "parallelquery",
        "global",
        "multimaster",
    )

    if engine_mode not in VALID_DB_ENGINE_MODES:
        raise ValueError(
            "DBCluster EngineMode must be one of: %s" % ", ".join(VALID_DB_ENGINE_MODES)
        )
    return engine_mode


def validate_license_model(license_model):
    """
    Validate LicenseModel for DBInstance
    Property: DBInstance.LicenseModel
    """

    VALID_LICENSE_MODELS = (
        "license-included",
        "bring-your-own-license",
        "general-public-license",
        "postgresql-license",
    )

    if license_model not in VALID_LICENSE_MODELS:
        raise ValueError(
            "DBInstance LicenseModel must be one of: %s"
            % ", ".join(VALID_LICENSE_MODELS)
        )
    return license_model


def validate_backup_window(window):
    """
    Validate PreferredBackupWindow for DBInstance
    Property: DBInstance.PreferredBackupWindow
    Property: DBCluster.PreferredBackupWindow
    """

    hour = r"[01]?[0-9]|2[0-3]"
    minute = r"[0-5][0-9]"
    r = (
        "(?P<start_hour>%s):(?P<start_minute>%s)-" "(?P<end_hour>%s):(?P<end_minute>%s)"
    ) % (hour, minute, hour, minute)
    range_regex = re.compile(r)
    m = range_regex.match(window)
    if not m:
        raise ValueError(
            "DBInstance PreferredBackupWindow must be in the " "format: hh24:mi-hh24:mi"
        )
    start_ts = (int(m.group("start_hour")) * 60) + int(m.group("start_minute"))
    end_ts = (int(m.group("end_hour")) * 60) + int(m.group("end_minute"))
    if abs(end_ts - start_ts) < 30:
        raise ValueError(
            "DBInstance PreferredBackupWindow must be at least " "30 minutes long."
        )
    return window


def validate_maintenance_window(window):
    """
    Validate PreferredMaintenanceWindow for DBInstance
    """

    days = ("Mon", "Tue", "Wed", "Thu", "Fri", "Sat", "Sun")
    day_re = r"[A-Z]{1}[a-z]{2}"
    hour = r"[01]?[0-9]|2[0-3]"
    minute = r"[0-5][0-9]"
    r = (
        "(?P<start_day>%s):(?P<start_hour>%s):(?P<start_minute>%s)-"
        "(?P<end_day>%s):(?P<end_hour>%s):(?P<end_minute>%s)"
    ) % (day_re, hour, minute, day_re, hour, minute)
    range_regex = re.compile(r)
    m = range_regex.match(window)
    if not m:
        raise ValueError(
            "DBInstance PreferredMaintenanceWindow must be in "
            "the format: ddd:hh24:mi-ddd:hh24:mi"
        )
    if m.group("start_day") not in days or m.group("end_day") not in days:
        raise ValueError(
            "DBInstance PreferredMaintenanceWindow day part of "
            "ranges must be one of: %s" % ", ".join(days)
        )
    start_ts = (
        (days.index(m.group("start_day")) * 24 * 60)
        + (int(m.group("start_hour")) * 60)
        + int(m.group("start_minute"))
    )
    end_ts = (
        (days.index(m.group("end_day")) * 24 * 60)
        + (int(m.group("end_hour")) * 60)
        + int(m.group("end_minute"))
    )
    if abs(end_ts - start_ts) < 30:
        raise ValueError(
            "DBInstance PreferredMaintenanceWindow must be at " "least 30 minutes long."
        )
    return window


def validate_backup_retention_period(days):
    """
    Validate BackupRetentionPeriod for DBInstance
    Property: DBInstance.BackupRetentionPeriod
    Property: DBCluster.BackupRetentionPeriod
    """

    days = positive_integer(days)
    if int(days) > 35:
        raise ValueError(
            "DBInstance BackupRetentionPeriod cannot be larger " "than 35 days."
        )
    return days


def validate_capacity(capacity):
    """
    Validate ScalingConfiguration capacity for serverless DBCluster
    Property: ScalingConfiguration.MaxCapacity
    Property: ScalingConfiguration.MinCapacity
    """

    VALID_MYSQL_SCALING_CONFIGURATION_CAPACITIES = (1, 2, 4, 8, 16, 32, 64, 128, 256)
    VALID_POSTGRESL_SCALING_CONFIGURATION_CAPACITIES = (2, 4, 8, 16, 32, 64, 192, 384)
    if (
        capacity not in VALID_POSTGRESL_SCALING_CONFIGURATION_CAPACITIES
        and capacity not in VALID_MYSQL_SCALING_CONFIGURATION_CAPACITIES
    ):
        raise ValueError(
            "ScalingConfiguration capacity must be one of: {}".format(
                ", ".join(
                    map(
                        str,
                        VALID_MYSQL_SCALING_CONFIGURATION_CAPACITIES
                        + VALID_POSTGRESL_SCALING_CONFIGURATION_CAPACITIES,
                    )
                )
            )
        )
    return capacity


def validate_v2_capacity(capacity):
    """
    Validate ServerlessV2ScalingConfiguration capacity for serverless DBCluster
    Property: ServerlessV2ScalingConfiguration.MinCapacity
    """
    if capacity < 0.5:
        raise ValueError(
            "ServerlessV2ScalingConfiguration capacity {} cannot be smaller than 0.5.".format(
                capacity
            )
        )
    if capacity > 128:
        raise ValueError(
            "ServerlessV2ScalingConfiguration capacity {} cannot be larger than 128.".format(
                capacity
            )
        )

    if capacity * 10 % 5 != 0:
        raise ValueError(
            "ServerlessV2ScalingConfiguration capacity {} cannot be only specific in half-step increments.".format(
                capacity
            )
        )

    return capacity


def validate_v2_max_capacity(capacity):
    """
    Validate ServerlessV2ScalingConfiguration max capacity for serverless DBCluster
    Property: ServerlessV2ScalingConfiguration.MaxCapacity
    """
    if capacity < 1:
        raise ValueError(
            "ServerlessV2ScalingConfiguration max capacity {} cannot be smaller than 1.".format(
                capacity
            )
        )

    return validate_v2_capacity(capacity)


def validate_dbinstance(self) -> None:
    """
    Class: DBInstance
    """
    if "DBSnapshotIdentifier" not in self.properties:
        if "Engine" not in self.properties:
            raise ValueError(
                "Resource Engine is required in type %s" % self.resource_type
            )

    if "SourceDBInstanceIdentifier" in self.properties:
        invalid_replica_properties = (
            "DBName",
            "MasterUsername",
            "MasterUserPassword",
            "PreferredBackupWindow",
            "MultiAZ",
            "DBSnapshotIdentifier",
        )

        invalid_properties = [
            s for s in self.properties.keys() if s in invalid_replica_properties
        ]

        if invalid_properties:
            raise ValueError(
                (
                    "{0} properties can't be provided when "
                    "SourceDBInstanceIdentifier is present "
                    "AWS::RDS::DBInstance."
                ).format(", ".join(sorted(invalid_properties)))
            )

    if (
        (
            "DBSnapshotIdentifier" not in self.properties
            and "SourceDBInstanceIdentifier" not in self.properties
        )
        and (
            "MasterUsername" not in self.properties
            or (
                "MasterUserPassword" not in self.properties
                and "ManageMasterUserPassword" not in self.properties
            )
        )
        and ("DBClusterIdentifier" not in self.properties)
    ):
        raise ValueError(
            r"Either (MasterUsername and either MasterUserPassword or ManageMasterUserPassword) or"
            r" DBSnapshotIdentifier are required in type "
            r"AWS::RDS::DBInstance."
        )

    if (
        "MasterUserPassword" in self.properties
        and "ManageMasterUserPassword" in self.properties
    ):
        raise ValueError(
            "Both MasterUserPassword and ManageMasterUserPassword cannot"
            " be set simultaneously."
        )

    if "KmsKeyId" in self.properties and "StorageEncrypted" not in self.properties:
        raise ValueError(
            "If KmsKeyId is provided, StorageEncrypted is required "
            "AWS::RDS::DBInstance."
        )

    nonetype = type(None)
    dbclusteridentifier = self.properties.get("DBClusterIdentifier", None)
    allocated_storage = self.properties.get("AllocatedStorage")
    avail_zone = self.properties.get("AvailabilityZone", None)
    multi_az = self.properties.get("MultiAZ", None)
    engine = self.properties.get("Engine")
    if not (
        isinstance(avail_zone, (AWSHelperFn, nonetype))
        and isinstance(multi_az, (AWSHelperFn, nonetype))
    ):
        if avail_zone and multi_az in [True, 1, "1", "true", "True"]:
            raise ValueError(
                "AvailabiltyZone cannot be set on "
                "DBInstance if MultiAZ is set to true."
            )

    storage_type = self.properties.get("StorageType", None)
    if (
        not dbclusteridentifier
        and storage_type
        and storage_type in ["io1"]
        and "Iops" not in self.properties
    ):
        raise ValueError("Must specify Iops if using StorageType io1")

    if (
        not dbclusteridentifier
        and storage_type
        and not isinstance(storage_type, (AWSHelperFn, nonetype))
        and engine
        and not isinstance(engine, (AWSHelperFn, nonetype))
        and engine in ["mariadb", "mysql", "postgres"]
        and storage_type in ["gp3"]
        and not isinstance(allocated_storage, AWSHelperFn)
        and int(allocated_storage) < 400
        and "Iops" in self.properties
    ):
        raise ValueError(
            "gp3 storage cannot have Iops specified when storage is less than 400GB for mariadb, mysql, postgres"
        )

    if (
        not dbclusteridentifier
        and storage_type
        and not isinstance(storage_type, (AWSHelperFn, nonetype))
        and engine
        and not isinstance(engine, (AWSHelperFn, nonetype))
        and "oracle" in engine
        and storage_type in ["gp3"]
        and not isinstance(allocated_storage, AWSHelperFn)
        and int(allocated_storage) < 200
        and "Iops" in self.properties
    ):
        raise ValueError(
            "gp3 storage cannot have Iops specified when storage is less than 200GB for oracle engine types"
        )

    iops = self.properties.get("Iops", None)
    if (
        not dbclusteridentifier
        and iops
        and not isinstance(iops, AWSHelperFn)
        and storage_type not in ["gp3"]
    ):
        min_storage_size = 100
        if not isinstance(engine, AWSHelperFn) and engine.startswith("sqlserver"):
            min_storage_size = 20

        if (
            not isinstance(allocated_storage, AWSHelperFn)
            and int(allocated_storage) < min_storage_size
        ):
            raise ValueError(
                f"AllocatedStorage must be at least {min_storage_size} when "
                "Iops is set."
            )
        if (
            not isinstance(allocated_storage, AWSHelperFn)
            and not isinstance(iops, AWSHelperFn)
            and float(iops) / float(allocated_storage) > 50.0
        ):
            raise ValueError(
                "AllocatedStorage must be no less than " "1/50th the provisioned Iops"
            )
    if (
        not dbclusteridentifier
        and iops
        and not isinstance(iops, AWSHelperFn)
        and storage_type in ["gp3"]
    ):
        # https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/CHAP_Storage.html#gp3-storage
        min_iops_to_allocated_storage_ratio = 0.0
        max_iops_to_allocated_storage_ratio = 500.0
        if engine in ["mariadb", "mysql", "postgres"]:
            min_storage_size = 400
        elif "oracle" in engine:
            min_storage_size = 200
        elif "sqlserver" in engine:
            min_storage_size = 20
            min_iops_to_allocated_storage_ratio = 0.5
        else:
            raise ValueError(
                f"StorageType gp3 is not supported for engine " f"{engine}"
            )
        # Validate storage size constraints when under certain sizes
        if (
            not isinstance(allocated_storage, AWSHelperFn)
            and int(allocated_storage) < min_storage_size
        ):
            raise ValueError(
                f"AllocatedStorage must be at least {min_storage_size} when "
                "Iops is set."
            )

        # Validate storage performance constraints for iops ratios
        if not (
            not isinstance(allocated_storage, AWSHelperFn)
            and not isinstance(iops, AWSHelperFn)
            and (
                min_iops_to_allocated_storage_ratio
                < iops / int(allocated_storage)
                < max_iops_to_allocated_storage_ratio
            )
        ):
            raise ValueError(
                "Invalid ratio of Iops to AllocatedStorage. Minimum ratio for "
                f"engine {engine} is {min_iops_to_allocated_storage_ratio} "
                f"and maximum ratio is {max_iops_to_allocated_storage_ratio}"
                f"current value is {iops / int(allocated_storage)}"
            )



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean, integer
from .validators.synthetics import canary_runtime_version


class S3Encryption(AWSProperty):
    """
    `S3Encryption <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-synthetics-canary-s3encryption.html>`__
    """

    props: PropsDictType = {
        "EncryptionMode": (str, False),
        "KmsKeyArn": (str, False),
    }


class ArtifactConfig(AWSProperty):
    """
    `ArtifactConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-synthetics-canary-artifactconfig.html>`__
    """

    props: PropsDictType = {
        "S3Encryption": (S3Encryption, False),
    }


class Code(AWSProperty):
    """
    `Code <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-synthetics-canary-code.html>`__
    """

    props: PropsDictType = {
        "Handler": (str, True),
        "S3Bucket": (str, False),
        "S3Key": (str, False),
        "S3ObjectVersion": (str, False),
        "Script": (str, False),
        "SourceLocationArn": (str, False),
    }


class RunConfig(AWSProperty):
    """
    `RunConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-synthetics-canary-runconfig.html>`__
    """

    props: PropsDictType = {
        "ActiveTracing": (boolean, False),
        "EnvironmentVariables": (dict, False),
        "MemoryInMB": (integer, False),
        "TimeoutInSeconds": (integer, False),
    }


class Schedule(AWSProperty):
    """
    `Schedule <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-synthetics-canary-schedule.html>`__
    """

    props: PropsDictType = {
        "DurationInSeconds": (str, False),
        "Expression": (str, True),
    }


class VPCConfig(AWSProperty):
    """
    `VPCConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-synthetics-canary-vpcconfig.html>`__
    """

    props: PropsDictType = {
        "SecurityGroupIds": ([str], True),
        "SubnetIds": ([str], True),
        "VpcId": (str, False),
    }


class BaseScreenshot(AWSProperty):
    """
    `BaseScreenshot <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-synthetics-canary-basescreenshot.html>`__
    """

    props: PropsDictType = {
        "IgnoreCoordinates": ([str], False),
        "ScreenshotName": (str, True),
    }


class VisualReference(AWSProperty):
    """
    `VisualReference <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-synthetics-canary-visualreference.html>`__
    """

    props: PropsDictType = {
        "BaseCanaryRunId": (str, True),
        "BaseScreenshots": ([BaseScreenshot], False),
    }


class Canary(AWSObject):
    """
    `Canary <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-synthetics-canary.html>`__
    """

    resource_type = "AWS::Synthetics::Canary"

    props: PropsDictType = {
        "ArtifactConfig": (ArtifactConfig, False),
        "ArtifactS3Location": (str, True),
        "Code": (Code, True),
        "ExecutionRoleArn": (str, True),
        "FailureRetentionPeriod": (integer, False),
        "Name": (str, True),
        "RunConfig": (RunConfig, False),
        "RuntimeVersion": (canary_runtime_version, True),
        "Schedule": (Schedule, True),
        "StartCanaryAfterCreation": (boolean, False),
        "SuccessRetentionPeriod": (integer, False),
        "Tags": (Tags, False),
        "VPCConfig": (VPCConfig, False),
        "VisualReference": (VisualReference, False),
    }


class Group(AWSObject):
    """
    `Group <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-synthetics-group.html>`__
    """

    resource_type = "AWS::Synthetics::Group"

    props: PropsDictType = {
        "Name": (str, True),
        "ResourceArns": ([str], False),
        "Tags": (Tags, False),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType
from .validators import boolean, integer


class ScaleInPolicy(AWSProperty):
    """
    `ScaleInPolicy <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kafkaconnect-connector-scaleinpolicy.html>`__
    """

    props: PropsDictType = {
        "CpuUtilizationPercentage": (integer, True),
    }


class ScaleOutPolicy(AWSProperty):
    """
    `ScaleOutPolicy <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kafkaconnect-connector-scaleoutpolicy.html>`__
    """

    props: PropsDictType = {
        "CpuUtilizationPercentage": (integer, True),
    }


class AutoScaling(AWSProperty):
    """
    `AutoScaling <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kafkaconnect-connector-autoscaling.html>`__
    """

    props: PropsDictType = {
        "MaxWorkerCount": (integer, True),
        "McuCount": (integer, True),
        "MinWorkerCount": (integer, True),
        "ScaleInPolicy": (ScaleInPolicy, True),
        "ScaleOutPolicy": (ScaleOutPolicy, True),
    }


class ProvisionedCapacity(AWSProperty):
    """
    `ProvisionedCapacity <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kafkaconnect-connector-provisionedcapacity.html>`__
    """

    props: PropsDictType = {
        "McuCount": (integer, False),
        "WorkerCount": (integer, True),
    }


class Capacity(AWSProperty):
    """
    `Capacity <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kafkaconnect-connector-capacity.html>`__
    """

    props: PropsDictType = {
        "AutoScaling": (AutoScaling, False),
        "ProvisionedCapacity": (ProvisionedCapacity, False),
    }


class Vpc(AWSProperty):
    """
    `Vpc <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kafkaconnect-connector-vpc.html>`__
    """

    props: PropsDictType = {
        "SecurityGroups": ([str], True),
        "Subnets": ([str], True),
    }


class ApacheKafkaCluster(AWSProperty):
    """
    `ApacheKafkaCluster <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kafkaconnect-connector-apachekafkacluster.html>`__
    """

    props: PropsDictType = {
        "BootstrapServers": (str, True),
        "Vpc": (Vpc, True),
    }


class KafkaCluster(AWSProperty):
    """
    `KafkaCluster <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kafkaconnect-connector-kafkacluster.html>`__
    """

    props: PropsDictType = {
        "ApacheKafkaCluster": (ApacheKafkaCluster, True),
    }


class KafkaClusterClientAuthentication(AWSProperty):
    """
    `KafkaClusterClientAuthentication <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kafkaconnect-connector-kafkaclusterclientauthentication.html>`__
    """

    props: PropsDictType = {
        "AuthenticationType": (str, True),
    }


class KafkaClusterEncryptionInTransit(AWSProperty):
    """
    `KafkaClusterEncryptionInTransit <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kafkaconnect-connector-kafkaclusterencryptionintransit.html>`__
    """

    props: PropsDictType = {
        "EncryptionType": (str, True),
    }


class CloudWatchLogsLogDelivery(AWSProperty):
    """
    `CloudWatchLogsLogDelivery <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kafkaconnect-connector-cloudwatchlogslogdelivery.html>`__
    """

    props: PropsDictType = {
        "Enabled": (boolean, True),
        "LogGroup": (str, False),
    }


class FirehoseLogDelivery(AWSProperty):
    """
    `FirehoseLogDelivery <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kafkaconnect-connector-firehoselogdelivery.html>`__
    """

    props: PropsDictType = {
        "DeliveryStream": (str, False),
        "Enabled": (boolean, True),
    }


class S3LogDelivery(AWSProperty):
    """
    `S3LogDelivery <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kafkaconnect-connector-s3logdelivery.html>`__
    """

    props: PropsDictType = {
        "Bucket": (str, False),
        "Enabled": (boolean, True),
        "Prefix": (str, False),
    }


class WorkerLogDelivery(AWSProperty):
    """
    `WorkerLogDelivery <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kafkaconnect-connector-workerlogdelivery.html>`__
    """

    props: PropsDictType = {
        "CloudWatchLogs": (CloudWatchLogsLogDelivery, False),
        "Firehose": (FirehoseLogDelivery, False),
        "S3": (S3LogDelivery, False),
    }


class LogDelivery(AWSProperty):
    """
    `LogDelivery <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kafkaconnect-connector-logdelivery.html>`__
    """

    props: PropsDictType = {
        "WorkerLogDelivery": (WorkerLogDelivery, True),
    }


class CustomPlugin(AWSProperty):
    """
    `CustomPlugin <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kafkaconnect-connector-customplugin.html>`__
    """

    props: PropsDictType = {
        "CustomPluginArn": (str, True),
        "Revision": (integer, True),
    }


class Plugin(AWSProperty):
    """
    `Plugin <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kafkaconnect-connector-plugin.html>`__
    """

    props: PropsDictType = {
        "CustomPlugin": (CustomPlugin, True),
    }


class WorkerConfiguration(AWSProperty):
    """
    `WorkerConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kafkaconnect-connector-workerconfiguration.html>`__
    """

    props: PropsDictType = {
        "Revision": (integer, True),
        "WorkerConfigurationArn": (str, True),
    }


class Connector(AWSObject):
    """
    `Connector <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kafkaconnect-connector.html>`__
    """

    resource_type = "AWS::KafkaConnect::Connector"

    props: PropsDictType = {
        "Capacity": (Capacity, True),
        "ConnectorConfiguration": (dict, True),
        "ConnectorDescription": (str, False),
        "ConnectorName": (str, True),
        "KafkaCluster": (KafkaCluster, True),
        "KafkaClusterClientAuthentication": (KafkaClusterClientAuthentication, True),
        "KafkaClusterEncryptionInTransit": (KafkaClusterEncryptionInTransit, True),
        "KafkaConnectVersion": (str, True),
        "LogDelivery": (LogDelivery, False),
        "Plugins": ([Plugin], True),
        "ServiceExecutionRoleArn": (str, True),
        "WorkerConfiguration": (WorkerConfiguration, False),
    }



# Copyright (c) 2012-2024, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

import re

from . import network_port


def validate_network_port(x):
    """
    Property: ReplicationGroup.Port
    Property: Endpoint.Port
    """
    return network_port(x)


def validate_node_group_id(node_group_id):
    """
    Property: NodeGroupConfiguration.NodeGroupId
    """

    if re.match(r"\d{1,4}", node_group_id):
        return node_group_id
    raise ValueError("Invalid NodeGroupId: %s" % node_group_id)


def validate_cache_cluster(self):
    """
    Class: CacheCluster
    """

    # Check that AZMode is "cross-az" if more than one Availability zone
    # is specified in PreferredAvailabilityZones
    preferred_azs = self.properties.get("PreferredAvailabilityZones")
    if (
        preferred_azs is not None
        and isinstance(preferred_azs, list)
        and len(preferred_azs) > 1
    ):
        if self.properties.get("AZMode") != "cross-az":
            raise ValueError(
                'AZMode must be "cross-az" if more than one a'
                "vailability zone is specified in PreferredAv"
                "ailabilityZones: http://docs.aws.amazon.com/"
                "AWSCloudFormation/latest/UserGuide/aws-prope"
                "rties-elasticache-cache-cluster.html#cfn-ela"
                "sticache-cachecluster-azmode"
            )


def validate_replication_group(self):
    """
    Class: ReplicationGroup
    """

    if (
        "NumCacheClusters" not in self.properties
        and "NumNodeGroups" not in self.properties
        and "ReplicasPerNodeGroup" not in self.properties
        and "PrimaryClusterId" not in self.properties
    ):
        raise ValueError(
            "One of PrimaryClusterId, NumCacheClusters, "
            "NumNodeGroups or ReplicasPerNodeGroup are required"
            "in type AWS::ElastiCache::ReplicationGroup"
        )



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean, integer
from .validators.cloudformation import Authentication  # noqa: F401
from .validators.cloudformation import AuthenticationBlock  # noqa: F401
from .validators.cloudformation import AWSCustomObject  # noqa: F401
from .validators.cloudformation import Init  # noqa: F401
from .validators.cloudformation import InitConfig  # noqa: F401
from .validators.cloudformation import InitConfigSets  # noqa: F401
from .validators.cloudformation import InitFile  # noqa: F401
from .validators.cloudformation import InitFileContext  # noqa: F401
from .validators.cloudformation import InitFiles  # noqa: F401
from .validators.cloudformation import InitService  # noqa: F401
from .validators.cloudformation import InitServices  # noqa: F401
from .validators.cloudformation import Metadata  # noqa: F401
from .validators.cloudformation import validate_int_to_str, validate_wait_condition


class CustomResource(AWSObject):
    """
    `CustomResource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cfn-customresource.html>`__
    """

    resource_type = "AWS::CloudFormation::CustomResource"

    props: PropsDictType = {
        "ServiceToken": (str, True),
    }


class HookDefaultVersion(AWSObject):
    """
    `HookDefaultVersion <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudformation-hookdefaultversion.html>`__
    """

    resource_type = "AWS::CloudFormation::HookDefaultVersion"

    props: PropsDictType = {
        "TypeName": (str, False),
        "TypeVersionArn": (str, False),
        "VersionId": (str, False),
    }


class HookTypeConfig(AWSObject):
    """
    `HookTypeConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudformation-hooktypeconfig.html>`__
    """

    resource_type = "AWS::CloudFormation::HookTypeConfig"

    props: PropsDictType = {
        "Configuration": (str, True),
        "ConfigurationAlias": (str, False),
        "TypeArn": (str, False),
        "TypeName": (str, False),
    }


class LoggingConfig(AWSProperty):
    """
    `LoggingConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloudformation-typeactivation-loggingconfig.html>`__
    """

    props: PropsDictType = {
        "LogGroupName": (str, False),
        "LogRoleArn": (str, False),
    }


class HookVersion(AWSObject):
    """
    `HookVersion <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudformation-hookversion.html>`__
    """

    resource_type = "AWS::CloudFormation::HookVersion"

    props: PropsDictType = {
        "ExecutionRoleArn": (str, False),
        "LoggingConfig": (LoggingConfig, False),
        "SchemaHandlerPackage": (str, True),
        "TypeName": (str, True),
    }


class Macro(AWSObject):
    """
    `Macro <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudformation-macro.html>`__
    """

    resource_type = "AWS::CloudFormation::Macro"

    props: PropsDictType = {
        "Description": (str, False),
        "FunctionName": (str, True),
        "LogGroupName": (str, False),
        "LogRoleARN": (str, False),
        "Name": (str, True),
    }


class ModuleDefaultVersion(AWSObject):
    """
    `ModuleDefaultVersion <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudformation-moduledefaultversion.html>`__
    """

    resource_type = "AWS::CloudFormation::ModuleDefaultVersion"

    props: PropsDictType = {
        "Arn": (str, False),
        "ModuleName": (str, False),
        "VersionId": (str, False),
    }


class ModuleVersion(AWSObject):
    """
    `ModuleVersion <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudformation-moduleversion.html>`__
    """

    resource_type = "AWS::CloudFormation::ModuleVersion"

    props: PropsDictType = {
        "ModuleName": (str, True),
        "ModulePackage": (str, True),
    }


class PublicTypeVersion(AWSObject):
    """
    `PublicTypeVersion <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudformation-publictypeversion.html>`__
    """

    resource_type = "AWS::CloudFormation::PublicTypeVersion"

    props: PropsDictType = {
        "Arn": (str, False),
        "LogDeliveryBucket": (str, False),
        "PublicVersionNumber": (str, False),
        "Type": (str, False),
        "TypeName": (str, False),
    }


class Publisher(AWSObject):
    """
    `Publisher <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudformation-publisher.html>`__
    """

    resource_type = "AWS::CloudFormation::Publisher"

    props: PropsDictType = {
        "AcceptTermsAndConditions": (boolean, True),
        "ConnectionArn": (str, False),
    }


class ResourceDefaultVersion(AWSObject):
    """
    `ResourceDefaultVersion <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudformation-resourcedefaultversion.html>`__
    """

    resource_type = "AWS::CloudFormation::ResourceDefaultVersion"

    props: PropsDictType = {
        "TypeName": (str, False),
        "TypeVersionArn": (str, False),
        "VersionId": (str, False),
    }


class ResourceVersion(AWSObject):
    """
    `ResourceVersion <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudformation-resourceversion.html>`__
    """

    resource_type = "AWS::CloudFormation::ResourceVersion"

    props: PropsDictType = {
        "ExecutionRoleArn": (str, False),
        "LoggingConfig": (LoggingConfig, False),
        "SchemaHandlerPackage": (str, True),
        "TypeName": (str, True),
    }


class Stack(AWSObject):
    """
    `Stack <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-stack.html>`__
    """

    resource_type = "AWS::CloudFormation::Stack"

    props: PropsDictType = {
        "NotificationARNs": ([str], False),
        "Parameters": (dict, False),
        "Tags": (Tags, False),
        "TemplateURL": (str, True),
        "TimeoutInMinutes": (integer, False),
    }


class AutoDeployment(AWSProperty):
    """
    `AutoDeployment <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloudformation-stackset-autodeployment.html>`__
    """

    props: PropsDictType = {
        "Enabled": (boolean, False),
        "RetainStacksOnAccountRemoval": (boolean, False),
    }


class ManagedExecution(AWSProperty):
    """
    `ManagedExecution <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloudformation-stackset-managedexecution.html>`__
    """

    props: PropsDictType = {
        "Active": (boolean, False),
    }


class OperationPreferences(AWSProperty):
    """
    `OperationPreferences <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloudformation-stackset-operationpreferences.html>`__
    """

    props: PropsDictType = {
        "FailureToleranceCount": (integer, False),
        "FailureTolerancePercentage": (integer, False),
        "MaxConcurrentCount": (integer, False),
        "MaxConcurrentPercentage": (integer, False),
        "RegionConcurrencyType": (str, False),
        "RegionOrder": ([str], False),
    }


class Parameter(AWSProperty):
    """
    `Parameter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloudformation-stackset-parameter.html>`__
    """

    props: PropsDictType = {
        "ParameterKey": (str, True),
        "ParameterValue": (str, True),
    }


class DeploymentTargets(AWSProperty):
    """
    `DeploymentTargets <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloudformation-stackset-deploymenttargets.html>`__
    """

    props: PropsDictType = {
        "AccountFilterType": (str, False),
        "Accounts": ([str], False),
        "AccountsUrl": (str, False),
        "OrganizationalUnitIds": ([str], False),
    }


class StackInstances(AWSProperty):
    """
    `StackInstances <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloudformation-stackset-stackinstances.html>`__
    """

    props: PropsDictType = {
        "DeploymentTargets": (DeploymentTargets, True),
        "ParameterOverrides": ([Parameter], False),
        "Regions": ([str], True),
    }


class StackSet(AWSObject):
    """
    `StackSet <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudformation-stackset.html>`__
    """

    resource_type = "AWS::CloudFormation::StackSet"

    props: PropsDictType = {
        "AdministrationRoleARN": (str, False),
        "AutoDeployment": (AutoDeployment, False),
        "CallAs": (str, False),
        "Capabilities": ([str], False),
        "Description": (str, False),
        "ExecutionRoleName": (str, False),
        "ManagedExecution": (ManagedExecution, False),
        "OperationPreferences": (OperationPreferences, False),
        "Parameters": ([Parameter], False),
        "PermissionModel": (str, True),
        "StackInstancesGroup": ([StackInstances], False),
        "StackSetName": (str, True),
        "Tags": (Tags, False),
        "TemplateBody": (str, False),
        "TemplateURL": (str, False),
    }


class TypeActivation(AWSObject):
    """
    `TypeActivation <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudformation-typeactivation.html>`__
    """

    resource_type = "AWS::CloudFormation::TypeActivation"

    props: PropsDictType = {
        "AutoUpdate": (boolean, False),
        "ExecutionRoleArn": (str, False),
        "LoggingConfig": (LoggingConfig, False),
        "MajorVersion": (str, False),
        "PublicTypeArn": (str, False),
        "PublisherId": (str, False),
        "Type": (str, False),
        "TypeName": (str, False),
        "TypeNameAlias": (str, False),
        "VersionBump": (str, False),
    }


class WaitCondition(AWSObject):
    """
    `WaitCondition <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-waitcondition.html>`__
    """

    resource_type = "AWS::CloudFormation::WaitCondition"

    props: PropsDictType = {
        "Count": (integer, False),
        "Handle": (str, False),
        "Timeout": (validate_int_to_str, False),
    }

    def validate(self):
        validate_wait_condition(self)


class WaitConditionHandle(AWSObject):
    """
    `WaitConditionHandle <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-waitconditionhandle.html>`__
    """

    resource_type = "AWS::CloudFormation::WaitConditionHandle"

    props: PropsDictType = {}



import unittest

from troposphere import Join
from troposphere.apigateway import GatewayResponse, Model


class TestModel(unittest.TestCase):
    def test_schema(self):
        # Check with no schema
        model = Model(
            "schema",
            RestApiId="apiid",
        )
        model.validate()

        # Check valid json schema string
        model = Model(
            "schema",
            RestApiId="apiid",
            Schema='{"a": "b"}',
        )
        model.validate()

        # Check invalid json schema string
        model = Model(
            "schema",
            RestApiId="apiid",
            Schema='{"a: "b"}',
        )
        with self.assertRaises(ValueError):
            model.validate()

        # Check accepting dict and converting to string in validate
        d = {"c": "d"}
        model = Model("schema", RestApiId="apiid", Schema=d)
        model.validate()
        self.assertEqual(model.properties["Schema"], '{"c": "d"}')

        # Check invalid Schema type
        with self.assertRaises(TypeError):
            model = Model("schema", RestApiId="apiid", Schema=1)

        # Check Schema being an AWSHelperFn
        model = Model(
            "schema",
            RestApiId="apiid",
            Schema=Join(":", ['{"a', ': "b"}']),
        )
        model.validate()


class TestGatewayResponse(unittest.TestCase):
    def test_response_type(self):
        gateway_response = GatewayResponse(
            "GatewayResponse",
            ResponseType="DEFAULT_4XX",
            RestApiId="apiid",
            StatusCode="200",
        )
        gateway_response.validate()

        with self.assertRaises(ValueError):
            gateway_response = GatewayResponse(
                "GatewayResponse",
                ResponseType="INVALID_RESPONSE_TYPE",
                RestApiId="apiid",
                StatusCode="200",
            )


if __name__ == "__main__":
    unittest.main()



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

import re

from ..compat import validate_policytype
from . import tags_or_list

Active = "Active"
Inactive = "Inactive"


def iam_group_name(group_name):
    """
    Property: Group.GroupName
    """
    if len(group_name) > 128:
        raise ValueError("IAM Role Name may not exceed 128 characters")
    iam_names(group_name)
    return group_name


def iam_names(b):
    iam_name_re = re.compile(r"^[a-zA-Z0-9_\.\+\=\@\-\,]+$")
    if iam_name_re.match(b):
        return b
    else:
        raise ValueError("%s is not a valid iam name" % b)


def iam_path(path):
    """
    Property: Group.Path
    Property: InstanceProfile.Path
    Property: ManagedPolicy.Path
    Property: Role.Path
    Property: User.Path
    """
    if len(path) > 512:
        raise ValueError("IAM path %s may not exceed 512 characters", path)

    iam_path_re = re.compile(r"^\/.*\/$|^\/$")
    if not iam_path_re.match(path):
        raise ValueError("%s is not a valid iam path name" % path)
    return path


def iam_role_name(role_name):
    """
    Property: Role.RoleName
    """
    if len(role_name) > 64:
        raise ValueError("IAM Role Name may not exceed 64 characters")
    iam_names(role_name)
    return role_name


def iam_user_name(user_name):
    """
    Property: User.UserName
    """
    if not user_name:
        raise ValueError("AWS::IAM::User property 'UserName' may not be empty")

    if len(user_name) > 64:
        raise ValueError(
            "AWS::IAM::User property 'UserName' may not exceed 64 characters"
        )

    iam_user_name_re = re.compile(r"^[\w+=,.@-]+$")
    if iam_user_name_re.match(user_name):
        return user_name
    else:
        raise ValueError(
            "%s is not a valid value for AWS::IAM::User property 'UserName'", user_name
        )


def policytypes(policy):
    """
    Property: ManagedPolicy.PolicyDocument
    Property: Policy.PolicyDocument
    Property: PolicyType.PolicyDocument
    Property: Role.AssumeRolePolicyDocument
    """
    return validate_policytype(policy)


def status(status):
    """
    Property: AccessKey.Status
    """

    valid_statuses = [Active, Inactive]

    if status not in valid_statuses:
        raise ValueError("Status needs to be one of %r" % valid_statuses)
    return status


def validate_tags_or_list(x):
    """
    Property: Role.Tags
    """
    return tags_or_list(x)



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.


def findingsfilter_action(action):
    """
    Property: FindingsFilter.Action
    """

    valid_actions = ["ARCHIVE", "NOOP"]

    if action not in valid_actions:
        raise ValueError('Action must be one of: "%s"' % (", ".join(valid_actions)))
    return action


def session_findingpublishingfrequency(frequency):
    """
    Property: Session.FindingPublishingFrequency
    """

    valid_frequencies = ["FIFTEEN_MINUTES", "ONE_HOUR", "SIX_HOURS"]

    if frequency not in valid_frequencies:
        raise ValueError(
            'FindingPublishingFrequency must be one of: "%s"'
            % (", ".join(valid_frequencies))
        )
    return frequency


def session_status(status):
    """
    Property: Session.Status
    """

    valid_status = ["ENABLED", "DISABLED"]

    if status not in valid_status:
        raise ValueError('Status must be one of: "%s"' % (", ".join(valid_status)))
    return status



import unittest

from troposphere import Template
from troposphere.iot1click import PlacementTemplate, Project


class TestPlacementTemplate(unittest.TestCase):
    def test_placement_template(self):
        template = Template()
        template.add_resource(
            Project(
                "BasicProject",
                ProjectName="project",
                Description="description",
                PlacementTemplate=PlacementTemplate(
                    DefaultAttributes={
                        "Attribute": "Value",
                        "Foo": "Bar",
                    },
                    DeviceTemplates={
                        "testbutton": {
                            "DeviceType": "button",
                        },
                    },
                ),
            )
        )
        template.to_json()



import unittest

from troposphere.appconfig import DeploymentStrategy, Validators


class TestAppconfigDeploymentStrategy(unittest.TestCase):
    def test_deploymentstrategy_growthtype_bad_value(self):
        with self.assertRaisesRegex(ValueError, "GrowthType must be one of"):
            DeploymentStrategy(
                "DeploymentStrategy",
                DeploymentDurationInMinutes=1,
                GrowthFactor=1,
                GrowthType="LINEA",
                Name="DeploymentStrategy",
                ReplicateTo="NONE",
            )

    def test_deploymentstrategy_replicateto_bad_value(self):
        with self.assertRaisesRegex(ValueError, "ReplicateTo must be one of"):
            DeploymentStrategy(
                "DeploymentStrategy",
                DeploymentDurationInMinutes=1,
                GrowthFactor=1,
                Name="DeploymentStrategy",
                ReplicateTo="none",
            )

    def test_deploymentstrategy(self):
        for replicate_to in ("NONE", "SSM_DOCUMENT"):
            DeploymentStrategy(
                "DeploymentStrategy",
                DeploymentDurationInMinutes=1,
                GrowthFactor=1,
                GrowthType="LINEAR",
                Name="DeploymentStrategy",
                ReplicateTo=replicate_to,
            )


class TestAppconfigValidators(unittest.TestCase):
    def test_validators_type_bad_value(self):
        with self.assertRaisesRegex(ValueError, "Validator Type must be one of"):
            Validators(Type="JSON_SCHEM")

    def test_validators_type(self):
        for validator_type in ("JSON_SCHEMA", "LAMBDA"):
            Validators(Type=validator_type)



import unittest

import troposphere.ecr as ecr
from troposphere import Tags


class TestECS(unittest.TestCase):
    def test_ecr_with_tags(self):
        repo = ecr.Repository(
            "ECRRepo",
            RepositoryName="myrepo",
            Tags=Tags(Name="myrepo"),
        )
        repo.to_dict()



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType
from .validators import integer


class BridgeNetworkOutput(AWSProperty):
    """
    `BridgeNetworkOutput <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediaconnect-bridgeoutput-bridgenetworkoutput.html>`__
    """

    props: PropsDictType = {
        "IpAddress": (str, True),
        "NetworkName": (str, True),
        "Port": (integer, True),
        "Protocol": (str, True),
        "Ttl": (integer, True),
    }


class BridgeOutputProperty(AWSProperty):
    """
    `BridgeOutputProperty <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediaconnect-bridge-bridgeoutput.html>`__
    """

    props: PropsDictType = {
        "NetworkOutput": (BridgeNetworkOutput, False),
    }


class VpcInterfaceAttachment(AWSProperty):
    """
    `VpcInterfaceAttachment <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediaconnect-flowsource-vpcinterfaceattachment.html>`__
    """

    props: PropsDictType = {
        "VpcInterfaceName": (str, False),
    }


class BridgeFlowSource(AWSProperty):
    """
    `BridgeFlowSource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediaconnect-bridgesource-bridgeflowsource.html>`__
    """

    props: PropsDictType = {
        "FlowArn": (str, True),
        "FlowVpcInterfaceAttachment": (VpcInterfaceAttachment, False),
    }


class BridgeNetworkSource(AWSProperty):
    """
    `BridgeNetworkSource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediaconnect-bridgesource-bridgenetworksource.html>`__
    """

    props: PropsDictType = {
        "MulticastIp": (str, True),
        "NetworkName": (str, True),
        "Port": (integer, True),
        "Protocol": (str, True),
    }


class BridgeSourceProperty(AWSProperty):
    """
    `BridgeSourceProperty <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediaconnect-bridge-bridgesource.html>`__
    """

    props: PropsDictType = {
        "FlowSource": (BridgeFlowSource, False),
        "NetworkSource": (BridgeNetworkSource, False),
    }


class EgressGatewayBridge(AWSProperty):
    """
    `EgressGatewayBridge <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediaconnect-bridge-egressgatewaybridge.html>`__
    """

    props: PropsDictType = {
        "MaxBitrate": (integer, True),
    }


class SourcePriority(AWSProperty):
    """
    `SourcePriority <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediaconnect-flow-sourcepriority.html>`__
    """

    props: PropsDictType = {
        "PrimarySource": (str, True),
    }


class FailoverConfig(AWSProperty):
    """
    `FailoverConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediaconnect-flow-failoverconfig.html>`__
    """

    props: PropsDictType = {
        "FailoverMode": (str, False),
        "RecoveryWindow": (integer, False),
        "SourcePriority": (SourcePriority, False),
        "State": (str, False),
    }


class IngressGatewayBridge(AWSProperty):
    """
    `IngressGatewayBridge <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediaconnect-bridge-ingressgatewaybridge.html>`__
    """

    props: PropsDictType = {
        "MaxBitrate": (integer, True),
        "MaxOutputs": (integer, True),
    }


class Bridge(AWSObject):
    """
    `Bridge <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconnect-bridge.html>`__
    """

    resource_type = "AWS::MediaConnect::Bridge"

    props: PropsDictType = {
        "EgressGatewayBridge": (EgressGatewayBridge, False),
        "IngressGatewayBridge": (IngressGatewayBridge, False),
        "Name": (str, True),
        "Outputs": ([BridgeOutputProperty], False),
        "PlacementArn": (str, True),
        "SourceFailoverConfig": (FailoverConfig, False),
        "Sources": ([BridgeSourceProperty], True),
    }


class BridgeOutput(AWSObject):
    """
    `BridgeOutput <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconnect-bridgeoutput.html>`__
    """

    resource_type = "AWS::MediaConnect::BridgeOutput"

    props: PropsDictType = {
        "BridgeArn": (str, True),
        "Name": (str, True),
        "NetworkOutput": (BridgeNetworkOutput, True),
    }


class BridgeSource(AWSObject):
    """
    `BridgeSource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconnect-bridgesource.html>`__
    """

    resource_type = "AWS::MediaConnect::BridgeSource"

    props: PropsDictType = {
        "BridgeArn": (str, True),
        "FlowSource": (BridgeFlowSource, False),
        "Name": (str, True),
        "NetworkSource": (BridgeNetworkSource, False),
    }


class Encryption(AWSProperty):
    """
    `Encryption <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediaconnect-flowsource-encryption.html>`__
    """

    props: PropsDictType = {
        "Algorithm": (str, False),
        "ConstantInitializationVector": (str, False),
        "DeviceId": (str, False),
        "KeyType": (str, False),
        "Region": (str, False),
        "ResourceId": (str, False),
        "RoleArn": (str, True),
        "SecretArn": (str, False),
        "Url": (str, False),
    }


class GatewayBridgeSource(AWSProperty):
    """
    `GatewayBridgeSource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediaconnect-flowsource-gatewaybridgesource.html>`__
    """

    props: PropsDictType = {
        "BridgeArn": (str, True),
        "VpcInterfaceAttachment": (VpcInterfaceAttachment, False),
    }


class Source(AWSProperty):
    """
    `Source <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediaconnect-flow-source.html>`__
    """

    props: PropsDictType = {
        "Decryption": (Encryption, False),
        "Description": (str, False),
        "EntitlementArn": (str, False),
        "GatewayBridgeSource": (GatewayBridgeSource, False),
        "IngestIp": (str, False),
        "IngestPort": (integer, False),
        "MaxBitrate": (integer, False),
        "MaxLatency": (integer, False),
        "MinLatency": (integer, False),
        "Name": (str, False),
        "Protocol": (str, False),
        "SenderControlPort": (integer, False),
        "SenderIpAddress": (str, False),
        "SourceArn": (str, False),
        "SourceIngestPort": (str, False),
        "SourceListenerAddress": (str, False),
        "SourceListenerPort": (integer, False),
        "StreamId": (str, False),
        "VpcInterfaceName": (str, False),
        "WhitelistCidr": (str, False),
    }


class Flow(AWSObject):
    """
    `Flow <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconnect-flow.html>`__
    """

    resource_type = "AWS::MediaConnect::Flow"

    props: PropsDictType = {
        "AvailabilityZone": (str, False),
        "Name": (str, True),
        "Source": (Source, True),
        "SourceFailoverConfig": (FailoverConfig, False),
    }


class FlowEntitlement(AWSObject):
    """
    `FlowEntitlement <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconnect-flowentitlement.html>`__
    """

    resource_type = "AWS::MediaConnect::FlowEntitlement"

    props: PropsDictType = {
        "DataTransferSubscriberFeePercent": (integer, False),
        "Description": (str, True),
        "Encryption": (Encryption, False),
        "EntitlementStatus": (str, False),
        "FlowArn": (str, True),
        "Name": (str, True),
        "Subscribers": ([str], True),
    }


class FlowOutputEncryption(AWSProperty):
    """
    `FlowOutputEncryption <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediaconnect-flowoutput-encryption.html>`__
    """

    props: PropsDictType = {
        "Algorithm": (str, False),
        "KeyType": (str, False),
        "RoleArn": (str, True),
        "SecretArn": (str, True),
    }


class FlowOutput(AWSObject):
    """
    `FlowOutput <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconnect-flowoutput.html>`__
    """

    resource_type = "AWS::MediaConnect::FlowOutput"

    props: PropsDictType = {
        "CidrAllowList": ([str], False),
        "Description": (str, False),
        "Destination": (str, False),
        "Encryption": (FlowOutputEncryption, False),
        "FlowArn": (str, True),
        "MaxLatency": (integer, False),
        "MinLatency": (integer, False),
        "Name": (str, False),
        "Port": (integer, False),
        "Protocol": (str, True),
        "RemoteId": (str, False),
        "SmoothingLatency": (integer, False),
        "StreamId": (str, False),
        "VpcInterfaceAttachment": (VpcInterfaceAttachment, False),
    }


class FlowSource(AWSObject):
    """
    `FlowSource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconnect-flowsource.html>`__
    """

    resource_type = "AWS::MediaConnect::FlowSource"

    props: PropsDictType = {
        "Decryption": (Encryption, False),
        "Description": (str, True),
        "EntitlementArn": (str, False),
        "FlowArn": (str, False),
        "GatewayBridgeSource": (GatewayBridgeSource, False),
        "IngestPort": (integer, False),
        "MaxBitrate": (integer, False),
        "MaxLatency": (integer, False),
        "MinLatency": (integer, False),
        "Name": (str, True),
        "Protocol": (str, False),
        "SenderControlPort": (integer, False),
        "SenderIpAddress": (str, False),
        "SourceListenerAddress": (str, False),
        "SourceListenerPort": (integer, False),
        "StreamId": (str, False),
        "VpcInterfaceName": (str, False),
        "WhitelistCidr": (str, False),
    }


class FlowVpcInterface(AWSObject):
    """
    `FlowVpcInterface <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconnect-flowvpcinterface.html>`__
    """

    resource_type = "AWS::MediaConnect::FlowVpcInterface"

    props: PropsDictType = {
        "FlowArn": (str, True),
        "Name": (str, True),
        "RoleArn": (str, True),
        "SecurityGroupIds": ([str], True),
        "SubnetId": (str, True),
    }


class GatewayNetwork(AWSProperty):
    """
    `GatewayNetwork <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediaconnect-gateway-gatewaynetwork.html>`__
    """

    props: PropsDictType = {
        "CidrBlock": (str, True),
        "Name": (str, True),
    }


class Gateway(AWSObject):
    """
    `Gateway <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconnect-gateway.html>`__
    """

    resource_type = "AWS::MediaConnect::Gateway"

    props: PropsDictType = {
        "EgressCidrBlocks": ([str], True),
        "Name": (str, True),
        "Networks": ([GatewayNetwork], True),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean, double, integer


class DocumentAttributeValue(AWSProperty):
    """
    `DocumentAttributeValue <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-documentattributevalue.html>`__
    """

    props: PropsDictType = {
        "DateValue": (str, False),
        "LongValue": (integer, False),
        "StringListValue": ([str], False),
        "StringValue": (str, False),
    }


class DocumentAttributeCondition(AWSProperty):
    """
    `DocumentAttributeCondition <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-documentattributecondition.html>`__
    """

    props: PropsDictType = {
        "ConditionDocumentAttributeKey": (str, True),
        "ConditionOnValue": (DocumentAttributeValue, False),
        "Operator": (str, True),
    }


class HookConfiguration(AWSProperty):
    """
    `HookConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-hookconfiguration.html>`__
    """

    props: PropsDictType = {
        "InvocationCondition": (DocumentAttributeCondition, False),
        "LambdaArn": (str, True),
        "S3Bucket": (str, True),
    }


class DocumentAttributeTarget(AWSProperty):
    """
    `DocumentAttributeTarget <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-documentattributetarget.html>`__
    """

    props: PropsDictType = {
        "TargetDocumentAttributeKey": (str, True),
        "TargetDocumentAttributeValue": (DocumentAttributeValue, False),
        "TargetDocumentAttributeValueDeletion": (boolean, False),
    }


class InlineCustomDocumentEnrichmentConfiguration(AWSProperty):
    """
    `InlineCustomDocumentEnrichmentConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-inlinecustomdocumentenrichmentconfiguration.html>`__
    """

    props: PropsDictType = {
        "Condition": (DocumentAttributeCondition, False),
        "DocumentContentDeletion": (boolean, False),
        "Target": (DocumentAttributeTarget, False),
    }


class CustomDocumentEnrichmentConfiguration(AWSProperty):
    """
    `CustomDocumentEnrichmentConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-customdocumentenrichmentconfiguration.html>`__
    """

    props: PropsDictType = {
        "InlineConfigurations": ([InlineCustomDocumentEnrichmentConfiguration], False),
        "PostExtractionHookConfiguration": (HookConfiguration, False),
        "PreExtractionHookConfiguration": (HookConfiguration, False),
        "RoleArn": (str, False),
    }


class ConfluenceAttachmentToIndexFieldMapping(AWSProperty):
    """
    `ConfluenceAttachmentToIndexFieldMapping <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-confluenceattachmenttoindexfieldmapping.html>`__
    """

    props: PropsDictType = {
        "DataSourceFieldName": (str, True),
        "DateFieldFormat": (str, False),
        "IndexFieldName": (str, True),
    }


class ConfluenceAttachmentConfiguration(AWSProperty):
    """
    `ConfluenceAttachmentConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-confluenceattachmentconfiguration.html>`__
    """

    props: PropsDictType = {
        "AttachmentFieldMappings": ([ConfluenceAttachmentToIndexFieldMapping], False),
        "CrawlAttachments": (boolean, False),
    }


class ConfluenceBlogToIndexFieldMapping(AWSProperty):
    """
    `ConfluenceBlogToIndexFieldMapping <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-confluenceblogtoindexfieldmapping.html>`__
    """

    props: PropsDictType = {
        "DataSourceFieldName": (str, True),
        "DateFieldFormat": (str, False),
        "IndexFieldName": (str, True),
    }


class ConfluenceBlogConfiguration(AWSProperty):
    """
    `ConfluenceBlogConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-confluenceblogconfiguration.html>`__
    """

    props: PropsDictType = {
        "BlogFieldMappings": ([ConfluenceBlogToIndexFieldMapping], False),
    }


class ConfluencePageToIndexFieldMapping(AWSProperty):
    """
    `ConfluencePageToIndexFieldMapping <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-confluencepagetoindexfieldmapping.html>`__
    """

    props: PropsDictType = {
        "DataSourceFieldName": (str, True),
        "DateFieldFormat": (str, False),
        "IndexFieldName": (str, True),
    }


class ConfluencePageConfiguration(AWSProperty):
    """
    `ConfluencePageConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-confluencepageconfiguration.html>`__
    """

    props: PropsDictType = {
        "PageFieldMappings": ([ConfluencePageToIndexFieldMapping], False),
    }


class ConfluenceSpaceToIndexFieldMapping(AWSProperty):
    """
    `ConfluenceSpaceToIndexFieldMapping <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-confluencespacetoindexfieldmapping.html>`__
    """

    props: PropsDictType = {
        "DataSourceFieldName": (str, True),
        "DateFieldFormat": (str, False),
        "IndexFieldName": (str, True),
    }


class ConfluenceSpaceConfiguration(AWSProperty):
    """
    `ConfluenceSpaceConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-confluencespaceconfiguration.html>`__
    """

    props: PropsDictType = {
        "CrawlArchivedSpaces": (boolean, False),
        "CrawlPersonalSpaces": (boolean, False),
        "ExcludeSpaces": ([str], False),
        "IncludeSpaces": ([str], False),
        "SpaceFieldMappings": ([ConfluenceSpaceToIndexFieldMapping], False),
    }


class DataSourceVpcConfiguration(AWSProperty):
    """
    `DataSourceVpcConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-datasourcevpcconfiguration.html>`__
    """

    props: PropsDictType = {
        "SecurityGroupIds": ([str], True),
        "SubnetIds": ([str], True),
    }


class ConfluenceConfiguration(AWSProperty):
    """
    `ConfluenceConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-confluenceconfiguration.html>`__
    """

    props: PropsDictType = {
        "AttachmentConfiguration": (ConfluenceAttachmentConfiguration, False),
        "BlogConfiguration": (ConfluenceBlogConfiguration, False),
        "ExclusionPatterns": ([str], False),
        "InclusionPatterns": ([str], False),
        "PageConfiguration": (ConfluencePageConfiguration, False),
        "SecretArn": (str, True),
        "ServerUrl": (str, True),
        "SpaceConfiguration": (ConfluenceSpaceConfiguration, False),
        "Version": (str, True),
        "VpcConfiguration": (DataSourceVpcConfiguration, False),
    }


class AclConfiguration(AWSProperty):
    """
    `AclConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-aclconfiguration.html>`__
    """

    props: PropsDictType = {
        "AllowedGroupsColumnName": (str, True),
    }


class DataSourceToIndexFieldMapping(AWSProperty):
    """
    `DataSourceToIndexFieldMapping <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-datasourcetoindexfieldmapping.html>`__
    """

    props: PropsDictType = {
        "DataSourceFieldName": (str, True),
        "DateFieldFormat": (str, False),
        "IndexFieldName": (str, True),
    }


class ColumnConfiguration(AWSProperty):
    """
    `ColumnConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-columnconfiguration.html>`__
    """

    props: PropsDictType = {
        "ChangeDetectingColumns": ([str], True),
        "DocumentDataColumnName": (str, True),
        "DocumentIdColumnName": (str, True),
        "DocumentTitleColumnName": (str, False),
        "FieldMappings": ([DataSourceToIndexFieldMapping], False),
    }


class ConnectionConfiguration(AWSProperty):
    """
    `ConnectionConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-connectionconfiguration.html>`__
    """

    props: PropsDictType = {
        "DatabaseHost": (str, True),
        "DatabaseName": (str, True),
        "DatabasePort": (integer, True),
        "SecretArn": (str, True),
        "TableName": (str, True),
    }


class SqlConfiguration(AWSProperty):
    """
    `SqlConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-sqlconfiguration.html>`__
    """

    props: PropsDictType = {
        "QueryIdentifiersEnclosingOption": (str, False),
    }


class DatabaseConfiguration(AWSProperty):
    """
    `DatabaseConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-databaseconfiguration.html>`__
    """

    props: PropsDictType = {
        "AclConfiguration": (AclConfiguration, False),
        "ColumnConfiguration": (ColumnConfiguration, True),
        "ConnectionConfiguration": (ConnectionConfiguration, True),
        "DatabaseEngineType": (str, True),
        "SqlConfiguration": (SqlConfiguration, False),
        "VpcConfiguration": (DataSourceVpcConfiguration, False),
    }


class GoogleDriveConfiguration(AWSProperty):
    """
    `GoogleDriveConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-googledriveconfiguration.html>`__
    """

    props: PropsDictType = {
        "ExcludeMimeTypes": ([str], False),
        "ExcludeSharedDrives": ([str], False),
        "ExcludeUserAccounts": ([str], False),
        "ExclusionPatterns": ([str], False),
        "FieldMappings": ([DataSourceToIndexFieldMapping], False),
        "InclusionPatterns": ([str], False),
        "SecretArn": (str, True),
    }


class S3Path(AWSProperty):
    """
    `S3Path <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-faq-s3path.html>`__
    """

    props: PropsDictType = {
        "Bucket": (str, True),
        "Key": (str, True),
    }


class OneDriveUsers(AWSProperty):
    """
    `OneDriveUsers <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-onedriveusers.html>`__
    """

    props: PropsDictType = {
        "OneDriveUserList": ([str], False),
        "OneDriveUserS3Path": (S3Path, False),
    }


class OneDriveConfiguration(AWSProperty):
    """
    `OneDriveConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-onedriveconfiguration.html>`__
    """

    props: PropsDictType = {
        "DisableLocalGroups": (boolean, False),
        "ExclusionPatterns": ([str], False),
        "FieldMappings": ([DataSourceToIndexFieldMapping], False),
        "InclusionPatterns": ([str], False),
        "OneDriveUsers": (OneDriveUsers, True),
        "SecretArn": (str, True),
        "TenantDomain": (str, True),
    }


class AccessControlListConfiguration(AWSProperty):
    """
    `AccessControlListConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-accesscontrollistconfiguration.html>`__
    """

    props: PropsDictType = {
        "KeyPath": (str, False),
    }


class DocumentsMetadataConfiguration(AWSProperty):
    """
    `DocumentsMetadataConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-documentsmetadataconfiguration.html>`__
    """

    props: PropsDictType = {
        "S3Prefix": (str, False),
    }


class S3DataSourceConfiguration(AWSProperty):
    """
    `S3DataSourceConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-s3datasourceconfiguration.html>`__
    """

    props: PropsDictType = {
        "AccessControlListConfiguration": (AccessControlListConfiguration, False),
        "BucketName": (str, True),
        "DocumentsMetadataConfiguration": (DocumentsMetadataConfiguration, False),
        "ExclusionPatterns": ([str], False),
        "InclusionPatterns": ([str], False),
        "InclusionPrefixes": ([str], False),
    }


class SalesforceChatterFeedConfiguration(AWSProperty):
    """
    `SalesforceChatterFeedConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-salesforcechatterfeedconfiguration.html>`__
    """

    props: PropsDictType = {
        "DocumentDataFieldName": (str, True),
        "DocumentTitleFieldName": (str, False),
        "FieldMappings": ([DataSourceToIndexFieldMapping], False),
        "IncludeFilterTypes": ([str], False),
    }


class SalesforceCustomKnowledgeArticleTypeConfiguration(AWSProperty):
    """
    `SalesforceCustomKnowledgeArticleTypeConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-salesforcecustomknowledgearticletypeconfiguration.html>`__
    """

    props: PropsDictType = {
        "DocumentDataFieldName": (str, True),
        "DocumentTitleFieldName": (str, False),
        "FieldMappings": ([DataSourceToIndexFieldMapping], False),
        "Name": (str, True),
    }


class SalesforceStandardKnowledgeArticleTypeConfiguration(AWSProperty):
    """
    `SalesforceStandardKnowledgeArticleTypeConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-salesforcestandardknowledgearticletypeconfiguration.html>`__
    """

    props: PropsDictType = {
        "DocumentDataFieldName": (str, True),
        "DocumentTitleFieldName": (str, False),
        "FieldMappings": ([DataSourceToIndexFieldMapping], False),
    }


class SalesforceKnowledgeArticleConfiguration(AWSProperty):
    """
    `SalesforceKnowledgeArticleConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-salesforceknowledgearticleconfiguration.html>`__
    """

    props: PropsDictType = {
        "CustomKnowledgeArticleTypeConfigurations": (
            [SalesforceCustomKnowledgeArticleTypeConfiguration],
            False,
        ),
        "IncludedStates": ([str], True),
        "StandardKnowledgeArticleTypeConfiguration": (
            SalesforceStandardKnowledgeArticleTypeConfiguration,
            False,
        ),
    }


class SalesforceStandardObjectAttachmentConfiguration(AWSProperty):
    """
    `SalesforceStandardObjectAttachmentConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-salesforcestandardobjectattachmentconfiguration.html>`__
    """

    props: PropsDictType = {
        "DocumentTitleFieldName": (str, False),
        "FieldMappings": ([DataSourceToIndexFieldMapping], False),
    }


class SalesforceStandardObjectConfiguration(AWSProperty):
    """
    `SalesforceStandardObjectConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-salesforcestandardobjectconfiguration.html>`__
    """

    props: PropsDictType = {
        "DocumentDataFieldName": (str, True),
        "DocumentTitleFieldName": (str, False),
        "FieldMappings": ([DataSourceToIndexFieldMapping], False),
        "Name": (str, True),
    }


class SalesforceConfiguration(AWSProperty):
    """
    `SalesforceConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-salesforceconfiguration.html>`__
    """

    props: PropsDictType = {
        "ChatterFeedConfiguration": (SalesforceChatterFeedConfiguration, False),
        "CrawlAttachments": (boolean, False),
        "ExcludeAttachmentFilePatterns": ([str], False),
        "IncludeAttachmentFilePatterns": ([str], False),
        "KnowledgeArticleConfiguration": (
            SalesforceKnowledgeArticleConfiguration,
            False,
        ),
        "SecretArn": (str, True),
        "ServerUrl": (str, True),
        "StandardObjectAttachmentConfiguration": (
            SalesforceStandardObjectAttachmentConfiguration,
            False,
        ),
        "StandardObjectConfigurations": (
            [SalesforceStandardObjectConfiguration],
            False,
        ),
    }


class ServiceNowKnowledgeArticleConfiguration(AWSProperty):
    """
    `ServiceNowKnowledgeArticleConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-servicenowknowledgearticleconfiguration.html>`__
    """

    props: PropsDictType = {
        "CrawlAttachments": (boolean, False),
        "DocumentDataFieldName": (str, True),
        "DocumentTitleFieldName": (str, False),
        "ExcludeAttachmentFilePatterns": ([str], False),
        "FieldMappings": ([DataSourceToIndexFieldMapping], False),
        "FilterQuery": (str, False),
        "IncludeAttachmentFilePatterns": ([str], False),
    }


class ServiceNowServiceCatalogConfiguration(AWSProperty):
    """
    `ServiceNowServiceCatalogConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-servicenowservicecatalogconfiguration.html>`__
    """

    props: PropsDictType = {
        "CrawlAttachments": (boolean, False),
        "DocumentDataFieldName": (str, True),
        "DocumentTitleFieldName": (str, False),
        "ExcludeAttachmentFilePatterns": ([str], False),
        "FieldMappings": ([DataSourceToIndexFieldMapping], False),
        "IncludeAttachmentFilePatterns": ([str], False),
    }


class ServiceNowConfiguration(AWSProperty):
    """
    `ServiceNowConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-servicenowconfiguration.html>`__
    """

    props: PropsDictType = {
        "AuthenticationType": (str, False),
        "HostUrl": (str, True),
        "KnowledgeArticleConfiguration": (
            ServiceNowKnowledgeArticleConfiguration,
            False,
        ),
        "SecretArn": (str, True),
        "ServiceCatalogConfiguration": (ServiceNowServiceCatalogConfiguration, False),
        "ServiceNowBuildVersion": (str, True),
    }


class SharePointConfiguration(AWSProperty):
    """
    `SharePointConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-sharepointconfiguration.html>`__
    """

    props: PropsDictType = {
        "CrawlAttachments": (boolean, False),
        "DisableLocalGroups": (boolean, False),
        "DocumentTitleFieldName": (str, False),
        "ExclusionPatterns": ([str], False),
        "FieldMappings": ([DataSourceToIndexFieldMapping], False),
        "InclusionPatterns": ([str], False),
        "SecretArn": (str, True),
        "SharePointVersion": (str, True),
        "SslCertificateS3Path": (S3Path, False),
        "Urls": ([str], True),
        "UseChangeLog": (boolean, False),
        "VpcConfiguration": (DataSourceVpcConfiguration, False),
    }


class ProxyConfiguration(AWSProperty):
    """
    `ProxyConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-proxyconfiguration.html>`__
    """

    props: PropsDictType = {
        "Credentials": (str, False),
        "Host": (str, True),
        "Port": (integer, True),
    }


class WebCrawlerBasicAuthentication(AWSProperty):
    """
    `WebCrawlerBasicAuthentication <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-webcrawlerbasicauthentication.html>`__
    """

    props: PropsDictType = {
        "Credentials": (str, True),
        "Host": (str, True),
        "Port": (integer, True),
    }


class WebCrawlerAuthenticationConfiguration(AWSProperty):
    """
    `WebCrawlerAuthenticationConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-webcrawlerauthenticationconfiguration.html>`__
    """

    props: PropsDictType = {
        "BasicAuthentication": ([WebCrawlerBasicAuthentication], False),
    }


class WebCrawlerSeedUrlConfiguration(AWSProperty):
    """
    `WebCrawlerSeedUrlConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-webcrawlerseedurlconfiguration.html>`__
    """

    props: PropsDictType = {
        "SeedUrls": ([str], True),
        "WebCrawlerMode": (str, False),
    }


class WebCrawlerSiteMapsConfiguration(AWSProperty):
    """
    `WebCrawlerSiteMapsConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-webcrawlersitemapsconfiguration.html>`__
    """

    props: PropsDictType = {
        "SiteMaps": ([str], True),
    }


class WebCrawlerUrls(AWSProperty):
    """
    `WebCrawlerUrls <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-webcrawlerurls.html>`__
    """

    props: PropsDictType = {
        "SeedUrlConfiguration": (WebCrawlerSeedUrlConfiguration, False),
        "SiteMapsConfiguration": (WebCrawlerSiteMapsConfiguration, False),
    }


class WebCrawlerConfiguration(AWSProperty):
    """
    `WebCrawlerConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-webcrawlerconfiguration.html>`__
    """

    props: PropsDictType = {
        "AuthenticationConfiguration": (WebCrawlerAuthenticationConfiguration, False),
        "CrawlDepth": (integer, False),
        "MaxContentSizePerPageInMegaBytes": (double, False),
        "MaxLinksPerPage": (integer, False),
        "MaxUrlsPerMinuteCrawlRate": (integer, False),
        "ProxyConfiguration": (ProxyConfiguration, False),
        "UrlExclusionPatterns": ([str], False),
        "UrlInclusionPatterns": ([str], False),
        "Urls": (WebCrawlerUrls, True),
    }


class WorkDocsConfiguration(AWSProperty):
    """
    `WorkDocsConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-workdocsconfiguration.html>`__
    """

    props: PropsDictType = {
        "CrawlComments": (boolean, False),
        "ExclusionPatterns": ([str], False),
        "FieldMappings": ([DataSourceToIndexFieldMapping], False),
        "InclusionPatterns": ([str], False),
        "OrganizationId": (str, True),
        "UseChangeLog": (boolean, False),
    }


class DataSourceConfiguration(AWSProperty):
    """
    `DataSourceConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-datasource-datasourceconfiguration.html>`__
    """

    props: PropsDictType = {
        "ConfluenceConfiguration": (ConfluenceConfiguration, False),
        "DatabaseConfiguration": (DatabaseConfiguration, False),
        "GoogleDriveConfiguration": (GoogleDriveConfiguration, False),
        "OneDriveConfiguration": (OneDriveConfiguration, False),
        "S3Configuration": (S3DataSourceConfiguration, False),
        "SalesforceConfiguration": (SalesforceConfiguration, False),
        "ServiceNowConfiguration": (ServiceNowConfiguration, False),
        "SharePointConfiguration": (SharePointConfiguration, False),
        "WebCrawlerConfiguration": (WebCrawlerConfiguration, False),
        "WorkDocsConfiguration": (WorkDocsConfiguration, False),
    }


class DataSource(AWSObject):
    """
    `DataSource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kendra-datasource.html>`__
    """

    resource_type = "AWS::Kendra::DataSource"

    props: PropsDictType = {
        "CustomDocumentEnrichmentConfiguration": (
            CustomDocumentEnrichmentConfiguration,
            False,
        ),
        "DataSourceConfiguration": (DataSourceConfiguration, False),
        "Description": (str, False),
        "IndexId": (str, True),
        "LanguageCode": (str, False),
        "Name": (str, True),
        "RoleArn": (str, False),
        "Schedule": (str, False),
        "Tags": (Tags, False),
        "Type": (str, True),
    }


class Faq(AWSObject):
    """
    `Faq <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kendra-faq.html>`__
    """

    resource_type = "AWS::Kendra::Faq"

    props: PropsDictType = {
        "Description": (str, False),
        "FileFormat": (str, False),
        "IndexId": (str, True),
        "Name": (str, True),
        "RoleArn": (str, True),
        "S3Path": (S3Path, True),
        "Tags": (Tags, False),
    }


class CapacityUnitsConfiguration(AWSProperty):
    """
    `CapacityUnitsConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-index-capacityunitsconfiguration.html>`__
    """

    props: PropsDictType = {
        "QueryCapacityUnits": (integer, True),
        "StorageCapacityUnits": (integer, True),
    }


class ValueImportanceItem(AWSProperty):
    """
    `ValueImportanceItem <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-index-valueimportanceitem.html>`__
    """

    props: PropsDictType = {
        "Key": (str, False),
        "Value": (integer, False),
    }


class Relevance(AWSProperty):
    """
    `Relevance <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-index-relevance.html>`__
    """

    props: PropsDictType = {
        "Duration": (str, False),
        "Freshness": (boolean, False),
        "Importance": (integer, False),
        "RankOrder": (str, False),
        "ValueImportanceItems": ([ValueImportanceItem], False),
    }


class Search(AWSProperty):
    """
    `Search <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-index-search.html>`__
    """

    props: PropsDictType = {
        "Displayable": (boolean, False),
        "Facetable": (boolean, False),
        "Searchable": (boolean, False),
        "Sortable": (boolean, False),
    }


class DocumentMetadataConfiguration(AWSProperty):
    """
    `DocumentMetadataConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-index-documentmetadataconfiguration.html>`__
    """

    props: PropsDictType = {
        "Name": (str, True),
        "Relevance": (Relevance, False),
        "Search": (Search, False),
        "Type": (str, True),
    }


class ServerSideEncryptionConfiguration(AWSProperty):
    """
    `ServerSideEncryptionConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-index-serversideencryptionconfiguration.html>`__
    """

    props: PropsDictType = {
        "KmsKeyId": (str, False),
    }


class JsonTokenTypeConfiguration(AWSProperty):
    """
    `JsonTokenTypeConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-index-jsontokentypeconfiguration.html>`__
    """

    props: PropsDictType = {
        "GroupAttributeField": (str, True),
        "UserNameAttributeField": (str, True),
    }


class JwtTokenTypeConfiguration(AWSProperty):
    """
    `JwtTokenTypeConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-index-jwttokentypeconfiguration.html>`__
    """

    props: PropsDictType = {
        "ClaimRegex": (str, False),
        "GroupAttributeField": (str, False),
        "Issuer": (str, False),
        "KeyLocation": (str, True),
        "SecretManagerArn": (str, False),
        "URL": (str, False),
        "UserNameAttributeField": (str, False),
    }


class UserTokenConfiguration(AWSProperty):
    """
    `UserTokenConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-kendra-index-usertokenconfiguration.html>`__
    """

    props: PropsDictType = {
        "JsonTokenTypeConfiguration": (JsonTokenTypeConfiguration, False),
        "JwtTokenTypeConfiguration": (JwtTokenTypeConfiguration, False),
    }


class Index(AWSObject):
    """
    `Index <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kendra-index.html>`__
    """

    resource_type = "AWS::Kendra::Index"

    props: PropsDictType = {
        "CapacityUnits": (CapacityUnitsConfiguration, False),
        "Description": (str, False),
        "DocumentMetadataConfigurations": ([DocumentMetadataConfiguration], False),
        "Edition": (str, True),
        "Name": (str, True),
        "RoleArn": (str, True),
        "ServerSideEncryptionConfiguration": (ServerSideEncryptionConfiguration, False),
        "Tags": (Tags, False),
        "UserContextPolicy": (str, False),
        "UserTokenConfigurations": ([UserTokenConfiguration], False),
    }
